@@ -68,8 +68,8 @@ if (isset($params['resultpage']))
   }
 if( !empty($resultpage) )
   {
-    $manager =& $gCms->GetHierarchyManager();
-    $node =& $manager->sureGetNodeByAlias($resultpage);
+    $manager = $gCms->GetHierarchyManager();
+    $node = $manager->sureGetNodeByAlias($resultpage);
     if (isset($node))
       {
 	$content = $node->GetContent();	
