@@ -444,7 +444,7 @@ while ($dbresult && ($row = $dbresult->FetchRow()))
   $filedir = cms_join_path($config['uploads_path'],$this->GetName(),'product_'.$row['id']);
   $onerow = cge_array::to_object($row);
   $pretty_url = '';
-  if( product_utils::can_do_pretty($params['notpretty']) ) {
+  if( product_utils::can_do_pretty('detail',$params) {
     $prettyurl = product_ops::pretty_url($row['id'],$detailpage);
   }
   
