@@ -79,6 +79,7 @@ if ( $row )
 
     // add canonical entry.
     $onerow->canonical = product_ops::pretty_url($row['id']);
+    $parms = array('productid'=>$params['productid']);
     $onerow->detail_url = $this->CreateLink($id,'details',$returnid,'',$parms,
 					    '',true,false,'',false,$onerow->canonical);
 
@@ -116,7 +117,7 @@ if ( $row )
 	$onerow->attributes = $tmp;
       }
 
-    $tmp = product_utils::get_product_attributes_full($row['id']);
+    $tmp = product_ops::get_product_attributes_full($row['id']);
     if( is_array($tmp) )
       {
 	$onerow->attribs_full = $tmp;
