@@ -55,7 +55,7 @@ $query = "SELECT A.*,count(B.attrib_text) AS count
           LEFT JOIN ".cms_db_prefix()."module_products_attributes B 
           ON A.attrib_set_id = B.attrib_set_id 
           WHERE product_id = ?
-          GROUP BY attrib_set_id";
+          GROUP BY A.attrib_set_id";
 $dbresult = $db->Execute( $query, array($params['compid']) );
 $objects = array();
 while( $dbresult && ($row = $dbresult->FetchRow()) )
