@@ -164,6 +164,10 @@ if (isset($params['submit']))
       {
 	$alias = product_ops::generate_alias($product_name);
       }
+    else
+      {
+	$alias = munge_string_to_url($alias);
+      }
 
     // check for duplicate alias
     if( product_ops::check_alias_used($alias,$compid) )
@@ -603,21 +607,21 @@ foreach( $selcategories as $one )
 }
 
 #Display template
-$this->smarty->assign('startform', $this->CreateFormStart($id, 'editproduct', $returnid, 'post', 'multipart/form-data'));
-$this->smarty->assign('endform', $this->CreateFormEnd());
-$this->smarty->assign('nametext', $this->Lang('name'));
-$this->smarty->assign('inputname', $this->CreateInputText($id, 'product_name', $product_name, 30, 255));
-$this->smarty->assign('pricetext', $this->Lang('price'));
+$smarty->assign('startform', $this->CreateFormStart($id, 'editproduct', $returnid, 'post', 'multipart/form-data'));
+$smarty->assign('endform', $this->CreateFormEnd());
+$smarty->assign('nametext', $this->Lang('name'));
+$smarty->assign('inputname', $this->CreateInputText($id, 'product_name', $product_name, 30, 255));
+$smarty->assign('pricetext', $this->Lang('price'));
 $smarty->assign('currency_symbol',product_ops::get_currency_symbol());
-$this->smarty->assign('inputprice', $this->CreateInputText($id, 'price', sprintf("%.2f",$price), 10, 12));
-$this->smarty->assign('weighttext', $this->Lang('weight'));
-$this->smarty->assign('weightunits',$this->GetPreference('products_weightunits'));
-$this->smarty->assign('inputweight', $this->CreateInputText($id, 'weight', 
-							    sprintf("%.2f",$weight), 10, 12));
-$this->smarty->assign('inputsku',$this->CreateInputText($id,'sku',$sku,10,25));
-$this->smarty->assign('inputalias',$this->CreateInputText($id,'alias',$alias,40,255));
-$this->smarty->assign('detailstext', $this->Lang('details'));
-$this->smarty->assign('inputdetails', $this->CreateTextArea(true, $id, $details, 'details', '', '', '', '', '80', '5'));
+$smarty->assign('inputprice', $this->CreateInputText($id, 'price', sprintf("%.2F",$price), 10, 12));
+$smarty->assign('weighttext', $this->Lang('weight'));
+$smarty->assign('weightunits',$this->GetPreference('products_weightunits'));
+$smarty->assign('inputweight', $this->CreateInputText($id, 'weight', 
+							    sprintf("%.2F",$weight), 10, 12));
+$smarty->assign('inputsku',$this->CreateInputText($id,'sku',$sku,10,25));
+$smarty->assign('inputalias',$this->CreateInputText($id,'alias',$alias,40,255));
+$smarty->assign('detailstext', $this->Lang('details'));
+$smarty->assign('inputdetails', $this->CreateTextArea(true, $id, $details, 'details', '', '', '', '', '80', '5'));
 
 if( count($catarray) > 0 ) {
   $n = count($catarray)/4;
