@@ -1,13 +1,11 @@
 <?php
 #BEGIN_LICENSE
 #-------------------------------------------------------------------------
-# Module: Products (c) 2008 by Robert Campbell 
+# Module: Products (c) 2012 by Robert Campbell 
 #         (calguy1000@cmsmadesimple.org)
 #  An addon module for CMS Made Simple to allow users to create, manage
 #  and display products in a variety of ways.
 # 
-# Version: 1.1.5
-#
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
 # This project's homepage is: http://www.cmsmadesimple.org
@@ -38,92 +36,50 @@
 #END_LICENSE
 if( !isset($gCms) ) exit;
 
-include(dirname(__FILE__).'/class.csv_importer.php');
-include(dirname(__FILE__).'/class.importImageHandler.php');
-
-$cge = $this->GetModuleInstance('CGExtensions');
-$fn = $cge->GetModulePath().'/lib/Progress2_Lite.php';
-include($fn);
+$go = 0;
+if( isset($params['go']) ) $go = 1;
 
 if( !isset($_SESSION['products_import_data']) ) die();
 $params = $_SESSION['products_import_data'];
-$batchsize = 50;
-$linenum = 0;
-$fpos = 0;
-if( isset($params['batchsize']) )
-  {
-    $batchsize = (int)$params['batchsize'];
-  }
-if( isset($params['linenum']) )
-  {
-    $linenum = (int)$params['linenum'];
-  }
-if( isset($params['fpos']) )
-  {
-    $fpos = (int)$params['fpos'];
-  }
+
+function progress($pct) {
+  echo '<script type="text/javascript">parent.progress('.$pct.');</script>';
+}
+function do_error($str) {
+  echo '<script type="text/javascript">parent.onError(\''.$str.'\');</script>';
+}
+function done() {
+  echo '<script type="text/javascript">parent.done();</script>';
+}
 
 // setup display
+if( $go == 1 ) {
+  $smarty->assign('processurl',$this->create_url($id,'importcsv',$returnid,
+						 array('showtemplate'=>'false')));
+  $url = $this->create_url($id,'defaultadmin',$returnid);
+  $smarty->assign('doneurl',str_replace('&amp;','&',$url));
+  echo $this->ProcessTemplate('importcsv.tpl');
+  return;
+}
 
-// begin theme
-$themeName=get_preference(get_userid(), 'admintheme', 'default');
-$themeObjectName = $themeName."Theme";
-$userid = get_userid();
-
-if (file_exists(dirname(__FILE__)."/themes/${themeName}/${themeObjectName}.php"))
-  {
-    include(dirname(__FILE__)."/themes/${themeName}/${themeObjectName}.php");
-    $themeObject = new $themeObjectName($gCms, $userid, $themeName);
-  }
- else
-   {
-     $themeObject = new AdminTheme($gCms, $userid, $themeName);
-   }
-
-//$gCms->variables['admintheme']=$themeObject;
-if (isset($gCms->config['admin_encoding']) && $gCms->config['admin_encoding'] != '')
-  {
-    $themeObject->SendHeaders(isset($charsetsent), $gCms->config['admin_encoding']);
-  }
- else
-   {
-     $themeObject->SendHeaders(isset($charsetsent), get_encoding('', false));
-   }
-$themeObject->PopulateAdminNavigation(isset($CMS_ADMIN_SUBTITLE)?$CMS_ADMIN_SUBTITLE:'');
-
-$themeObject->DisplayDocType();
-$themeObject->DisplayHTMLStartTag();
-//$themeObject->DisplayHTMLHeader(false, isset($headtext)?$headtext:'');
-$themeObject->DisplayBodyTag();
-//$themeObject->DoTopMenu();
-$themeObject->DisplayMainDivStart();
-
-$opts = array('left'=>50,'top'=>50,'width'=>300,'height'=>25,
-	      'min'=>1,'max'=>100);
-
-$pg1 = new HTML_Progress2_Lite($opts);
-$pg1->addLabel('text','txt1',$this->Lang('progress'));
-$smarty->assign('progressbar',$pg1->toHtml());
-echo $this->ProcessTemplate('importcsv.tpl');
-$pg1->show();
-
-$themeObject->DisplayMainDivEnd();
-//$themeObject->OutputFooterJavascript();
-//$themeObject->DisplayFooter();
-// end theme
-
+set_time_limit(0);                   // ignore php timeout
+ignore_user_abort(true);             // keep on going even if user pulls the plug*
+while(ob_get_level())ob_end_clean(); // remove output buffers
+ob_implicit_flush(true);             // output stuff directly
 
 
 // begin work
+echo '<!DOCTYPE html><html><head></head><body>'; // webkit hotfix
+
 $config = $gCms->GetConfig();
 $fn = $config['root_path'].'/tmp/cache/'.$params['filename'];
-$the_filesize = filesize($fn);
 $fh = fopen($fn,'r');
 if( !$fh )
   {
-    echo $this->Lang('error_fileopen');
+    error($this->Lang('error_fileopen'));
     return;
   }
+$filesize = filesize($fn);
 
 $imageHandler = new importImageHandler($this);
 $imageHandler->setSourceLocation(cms_join_path($config['uploads_path'],$params['imagepath']));
@@ -138,63 +94,37 @@ $importer->setPolicyValue('handle_images',(int)$params['handleimages']);
 $importer->setPolicyValue('create_hierarchy',(int)$params['createhierarchy']);
 $importer->setPolicyValue('create_categories',(int)$params['createcategories']);
 $importer->setPolicyValue('image_source_location',$params['imagepath']);
-$importer->setPolicyValue('skip_existing_products',$params['duplicateproducts'] == 'skip');
+$importer->setPolicyValue('on_duplicate_product',trim($params['duplicateproducts']));
+$importer->setPolicyValue('clearfields',(int)$params['clearfields']);
+$importer->setPolicyValue('clearattribs',(int)$params['clearattribs']);
+$importer->setPolicyValue('clearcategories',(int)$params['clearcategories']);
 
-$batchlines = 0;
-if( $fpos > 0 )
-  {
-    // process the first line again.
-    $line = $importer->get_unparsed_record($fh);
-    $line = trim($line);
-    if( empty($line) ) continue;
-    $res = $importer->handleLine($line);
-
-    // seek to our old position.
-    fseek($fh,$fpos);
-  }
-while( !feof($fh) && $batchlines < $batchsize )
+while( !feof($fh) )
   {
     $line = $importer->get_unparsed_record($fh);
     $line = trim($line);
-    $linenum++;
-    $batchlines++;
     $pos = ftell($fh);
-    $pg1->moveStep((int)($pos / $the_filesize * 100.0));
     if( empty($line) ) continue;
 
+    $pct = (int)($pos / $filesize * 100.0);
+    progress($pct);
+
     $res = $importer->handleLine($line);
-  }
-if( !feof($fh) )
-  {
-    // ready for the next batch
-
-    // save any errors
-
-    // save our position
-    $pos = ftell($fh);
-    fclose($fh);
-    $_SESSION['products_import_data']['fpos'] = $pos;
-    $_SESSION['products_import_data']['linenum'] = $linenum;
-    
-    // now redirect
-    $parms = array();
-    $parms['disable_buffer'] = 1;
-    $parms['disable_theme'] = 1;
-    $url = $this->CreateURL($id,'importcsv','',$parms);
-    redirect(cge_url::current_url());
+    if( !$res ) {
+      $errors = $importer->getErrors();
+      $importer->clearErrors();
+      if( is_array($errors) && count($errors) ) {
+	foreach( $errors as $one ) {
+	  do_error($one);
+	}
+      }
+    }
   }
 
 // woot, we're done
 fclose($fh);
-
-$errors = $importer->getErrors();
-if( is_array($errors) )
-  {
-    foreach( $errors as $one )
-      {
-	echo "$one<br/>";
-      }
-  }
+done();
+exit();
 
 #
 # EOF
