@@ -64,6 +64,16 @@ $pagenumber = 1;
 $fields_viewable = array();
 $field_names = array();
 
+if( isset($params['reset']) ) {
+  set_preference($uid,'products_sel_hierarchy','');
+  set_preference($uid,'products_sel_children',0);
+  set_preference($uid,'products_sel_pagelimit',25);
+  set_preference($uid,'products_sel_sortby','create_date');
+  set_preference($uid,'products_sel_sortorder','desc');
+  set_preference($uid,'products_sel_excludecats',0);
+  set_preference($uid,'products_sel_categories','');
+}
+
 //
 // Get preferences
 //
@@ -79,6 +89,7 @@ if( !empty($tmp) ) $categories = explode(',',$tmp);
 $custom_fields = '';
 $tmp = get_preference('uid','products_sel_customfields','');
 if( !empty($tmp) ) $custom_fields = explode(',',$tmp);
+$filterinuse = ($hierarchy != '' || $children != 0 || (is_array($categories) && count($categories)) || $excludecats != 0 );
 
 //
 // Handle Get parameters
@@ -136,10 +147,9 @@ if( isset($params['submit']) )
   if( is_array($tmp) && count($tmp) )
     {
       $category_list = array();
-      for( $i = 0; $i < count($tmp); $i++ )
-	{
-	  $category_list[$tmp[$i]->id] = $tmp[$i]->name;
-	}
+      foreach( $tmp as $one ) {
+	$category_list[$one->id] = $one->name;
+      }
       $smarty->assign('category_list',$category_list);
     }
 }
@@ -374,6 +384,10 @@ $smarty->assign('importlink',
 		$this->CreateImageLink($id,'importproducts',$returnid,
 				       $this->Lang('import_from_csv'),
 				       'icons/system/import.gif',array(),'','',false));
+$smarty->assign('exportlink',
+		$this->CreateImageLink($id,'exportcsv',$returnid,
+				       $this->Lang('export_to_csv'),
+				       'icons/system/export.gif',array(),'','',false));
 $this->smarty->assign('addlink', 
 		      $this->CreateLink($id, 'addproduct', $returnid, 
 					$gCms->variables['admintheme']->DisplayImage('icons/system/newfolder.gif', $this->Lang('addproduct'),'','','systemicon'), 
@@ -388,6 +402,7 @@ $smarty->assign('weight_units',product_ops::get_weight_units());
 $smarty->assign('weighttext',$this->Lang('weight'));
 $smarty->assign('formstart2',$this->CreateFormStart($id,'admin_bulkaction',$returnid));
 $smarty->assign('formend2',$this->CreateFormEnd());
+$smarty->assign('filterinuse',$filterinuse);
 $bulkactions = array();
 $bulkactions['delete'] = $this->Lang('delete');
 $bulkactions['setdraft'] = $this->Lang('setdraft');
