@@ -12,6 +12,7 @@ $lang['add_category_field'] = 'Associe un champ &agrave; la cat&eacute;gorie : &
 $lang['add_hierarchy_item'] = 'Ajoute une hi&eacute;rarchie d&#039;article';
 $lang['add_option'] = 'Ajouter une option d&#039;attribut';
 $lang['admin_only'] = 'Seuls les administrateurs peuvent voir cet attribut ?';
+$lang['advanced'] = 'Avanc&eacute;';
 $lang['align_ul'] = 'Haut gauche';
 $lang['align_uc'] = 'Haut centre';
 $lang['align_ur'] = 'Haut droit';
@@ -29,6 +30,7 @@ $lang['areyousure_deleteproduct'] = '&Ecirc;tes-vous s&ucirc;r de vouloir suppri
 $lang['ascending'] = 'Ascendant';
 $lang['attribute_name'] = 'Nom de l&#039;attribut';
 $lang['automatic'] = 'Automatique';
+$lang['btn_setecomhandlers'] = 'Installer les gestionnaires d&#039;&eacute;v&egrave;nements E-commerce';
 $lang['byhierarchytemplates'] = 'Gabarits de hi&eacute;rarchie';
 $lang['byhierarchytemplate_addedit'] = 'Ajouter/Editer un gabarit de hi&eacute;rarchie';
 $lang['cancel'] = 'Annuler';
@@ -87,6 +89,7 @@ $lang['error_missingparam'] = 'Un param&egrave;tre requis est manquant ou invali
 $lang['error_nameused'] = 'Un &eacute;l&eacute;ment portant ce nom existe d&eacute;j&agrave;';
 $lang['error_nofieldtype'] = 'Choisisser le type du champ';
 $lang['error_noname'] = 'Un nom doit &ecirc;tre indiqu&eacute;';
+$lang['error_onequantityfield'] = 'Seul un champ de quantit&eacute; est autoris&eacute;';
 $lang['error_onesubscriptionfield'] = 'Un seul champs de souscription est autoris&eacute;';
 $lang['error_permissiondenied'] = 'Permission refus&eacute;e';
 $lang['error_product_aliasused'] = 'L&#039;alias sp&eacute;cifi&eacute; est d&eacute;j&agrave; utilis&eacute;';
@@ -94,13 +97,16 @@ $lang['error_product_nameused'] = 'Un produit portant ce nom existe d&eacute;j&a
 $lang['error_product_notfound'] = 'Le produit d&eacute;sir&eacute; n&#039;a pas pu &ecirc;tre retrouv&eacute;';
 $lang['error_product_skuused'] = 'Cette valeur SKU est d&eacute;j&agrave; utilis&eacute;e par un autre produit';
 $lang['error_price_adjustment'] = 'La valeur d&#039;ajustement du prix est invalide pour l&#039;objet %s';
+$lang['error_sku_required'] = 'Merci d&#039;entrer un SKU unique';
 $lang['error_upload_failed'] = 'L&#039;envoi du fichier a &eacute;chou&eacute; : %s';
+$lang['exclude_categories'] = 'Exclure les produits des cat&eacute;gories s&eacute;lectionn&eacute;es des r&eacute;sultats';
 $lang['expire_six_months'] = 'Apr&egrave;s six mois';
 $lang['expire_one_year'] = 'Apr&egrave;s un an';
 $lang['expire_two_year'] = 'Apr&egrave;s deux ans';
 $lang['extra1'] = 'Champ suppl&eacute;mentaire 1';
 $lang['extra2'] = 'Champ suppl&eacute;mentaire 2';
 $lang['field'] = 'Champ';
+$lang['fields'] = 'Champs';
 $lang['fielddef'] = 'D&eacute;finition d&#039;un champ';
 $lang['fielddefs'] = 'D&eacute;finitions des champs';
 $lang['file'] = 'Fichier';
@@ -204,11 +210,14 @@ $lang['info_fieldproblems'] = 'Une erreur est survenue lors du traitement d&#039
 $lang['info_handleimages'] = 'Lors de l&#039;importation, si un nom de fichier image est trouv&eacute; dans une colonne, faut-il le d&eacute;placer de son r&eacute;pertoire d&#039;origine, lui ajouter un filigrane, cr&eacute;er une miniature, et changer le type du champ associ&eacute; en champ &quot;image&quot; ?';
 $lang['info_hierpage'] = 'Par d&eacute;faut, utiliser cette page pour la vue de hierarchie. L&#039;ID de la page ne sera pas sp&eacute;cifi&eacute; dans l&#039;URL.';
 $lang['info_imagepath'] = 'Chemin (relatif au r&eacute;pertoire uploads) des images r&eacute;f&eacute;renc&eacute;es par le fichier import&eacute; ';
+$lang['info_imagestuff_deprecated'] = 'Les fonctions de traitement d&#039;images sont d&eacute;pr&eacute;ci&eacute;es et vont &ecirc;tre supprim&eacute;es dans une future version. Utilisez le module CGSmartImage pour le traitement d&#039;images.';
 $lang['info_import_test_passed'] = 'Apr&egrave;s un examen pr&eacute;liminaire, le fichier semble correct.<br/>Cependant, il se peut qu&#039;il contienne tout de m&ecirc;me des erreurs qui ne pourront &ecirc;tre d&eacute;tect&eacute;es que lors de l&#039;importation.';
 $lang['info_prettyhierurls'] = 'Inclure le nom de la hi&eacute;rarchie dans l&#039;URL';
 $lang['info_price_adjustment'] = 'Les valeurs valides sont +-*#.##';
 $lang['info_prodnotfound'] = 'Cette option param&egrave;tre le comportement du site lorsqu&#039;une fiche produit est affich&eacute;e directement &agrave; la saisie d&#039;une URL, et que ce produit ne peut &ecirc;tre affich&eacute; (pour toutes raisons : d&eacute;sactiv&eacute;, supprim&eacute;, etc.).';
 $lang['info_publicfield'] = 'Les champs publics sont visibles par les utilisateurs.';
+$lang['info_reorder_content'] = 'This operation allows dragging the individual nodes in the tree to adjustth order that they will be displayed in in the hierarchy view';
+$lang['info_setecomhandlers'] = 'Cette fonction va s&#039;assurer que tous les gestionnaires d&#039;&eacute;v&egrave;nements E-commerce sont install&eacute;s. Ceci est utile lorsque vous souhaitez g&eacute;rer les stocks / quantit&eacute;s et que les gestionnaires n&#039;ont pas &eacute;t&eacute;s mis en place lors de l&#039;installation ou la mise &agrave; jour.';
 $lang['label'] = '&Eacute;tiquette';
 $lang['label_skip'] = 'Ignorer';
 $lang['label_overwrite'] = 'Ecraser';
@@ -220,6 +229,7 @@ $lang['modifieddate'] = 'Date de modification';
 $lang['module_description'] = 'Un module de gestion d&#039;un catalogue de produits, de leurs prix, images, etc. Permet aussi aux utilisateurs de remplir un panier d&#039;achat.';
 $lang['move_down'] = 'Descendre';
 $lang['move_up'] = 'Remonter';
+$lang['msg_eventhandlers_created'] = 'Gestionnaires d&#039;&eacute;v&egrave;nements cr&eacute;es';
 $lang['name'] = 'Nom';
 $lang['needpermission'] = 'Vous n&#039;avez pas la permission requise&nbsp;: %s';
 $lang['new_category_name'] = 'Nouveau nom de cat&eacute;gorie';
@@ -227,7 +237,10 @@ $lang['nextpage'] = '&amp;gt;';
 $lang['no'] = 'Non';
 $lang['nonamegiven'] = 'Vous n&#039;avez pas donn&eacute; de nom';
 $lang['none'] = 'Aucun';
+$lang['nothing_selectd'] = 'Vous n&#039;avez rien s&eacute;lectionn&eacute;';
 $lang['of'] = 'de';
+$lang['operation_cancelled'] = 'Op&eacute;ration annul&eacute;e';
+$lang['operation_complete'] = 'Op&eacute;ration r&eacute;alis&eacute;e';
 $lang['page'] = 'Page ';
 $lang['page_of'] = 'Page %s sur %s';
 $lang['page_limit'] = 'El&eacute;ments par page';
@@ -245,10 +258,12 @@ $lang['param_action'] = 'Sp&eacute;cifie le comportement du module. Les valeurs
   <li>search - Afficher un formulaire de recherche de produits multi-crit&egrave;res</li>
 </ul>';
 $lang['param_category'] = 'Lors de l&#039;utilisation en mode sommaire (<em>default</em>), ce param&egrave;tre, qui devrait correspondre au nom d&#039;une cat&eacute;gorie existante, sera utilis&eacute; pour afficher seulement les entr&eacute;es qui sont dans cette cat&eacute;gorie (une liste s&eacute;par&eacute;e par des virgules peut &ecirc;tre fournie)';
+$lang['param_categoryfield'] = 'Utilis&eacute; seulement action l&#039;action <em>categorylist</em>, ce param&egrave;tre peut &ecirc;tre utilis&eacute; pour filtrer les cat&eacute;gories en se basant sur une valeur d&#039;un champ de cat&eacute;gorie. Il ne fonctionnera pas avec les param&egrave;tres <em>category</em> ou <em>category_id</em>. La syntaxe de ce param&egrave;tre est une liste de noms de champs et de valeurs s&eacute;par&eacute;es par des virgules.  Par exemple : categorylist=&quot;nom_champ:valeur,nom_champ2:valeur_2&quot;';
 $lang['param_categorylisttemplate'] = 'Utilis&eacute; seulement avec l&#039;action <em>categorylist</em>, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
 $lang['param_categorylistdtltemplate'] = 'Utilis&eacute; seulement avec l&#039;action <em>categorylist</em>, ce param&egrave;tre indique quel gabarit doit &ecirc;tre utilis&eacute; pour l&#039;affichage du d&eacute;tail d&#039;une cat&eacute;gorie. Ce param&egrave;tre utilise un gabarit de liste de cat&eacute;gories... Si aucune valeur n&#039;est sp&eacute;cifi&eacute;e, c&#039;est le gabarit par d&eacute;faut de ce type qui est utilis&eacute;.';
 $lang['param_detailpage'] = 'Sp&eacute;cifie l&#039;id ou l&#039;alias de la page qui doit &ecirc;tre utilis&eacute;e pour afficher le d&eacute;tail.';
 $lang['param_detailtemplate'] = 'Ce param&egrave;tre sp&eacute;cifie quel gabarit devrait &ecirc;tre utilis&eacute; pour l&#039;affichage en mode d&eacute;tails. Si aucune valeur n&#039;est fournie, le gabarit par d&eacute;faut actuel de ce type est utilis&eacute;.';
+$lang['param_excludecat'] = 'Utilis&eacute; seulement avec l&#039;action par d&eacute;faut (summary), ce param&egrave;tre vous permet d&#039;exclure les produits de certaines cat&eacute;gories du r&eacute;sultat. Vous pouvez utiliser une liste de noms de cat&eacute;gories s&eacute;par&eacute;s par des virgules. Ce param&egrave;tre peut fonctionner en conjonction avec le param&egrave;tre <em>category</em> pour afficher une liste de produits qui sont dans une cat&eacute;gorie mais pas dans d&#039;autres.';
 $lang['param_field'] = 'Utilis&eacute; seulement avec l&#039;action <em>fieldlist</em>, ce param&egrave;tre est obligatoire pour pr&eacute;ciser le nom du champ produit &agrave; utiliser pour cr&eacute;er la liste d&eacute;roulante.';
 $lang['param_fieldval'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre permet de sp&eacute;cifier la valeur d&#039;un champ pour limiter les r&eacute;sultats affich&eacute;s. Valeurs sp&eacute;ciales possibles : &quot;::null::&quot; - &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Utilis&eacute; seulement avec l&#039;action <em>default</em>, ce param&egrave;tre indique que seuls les produits appartenant &agrave; cet &eacute;l&eacute;ment de hi&eacute;rarchie doivent &ecirc;tre affich&eacute;s.  Des jokers peuvent &ecirc;tre utilis&eacute;s pour &eacute;tendre l&#039;affichage aux parent ou enfants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie indiqu&eacute;.  Par exemple {Products hierarchy=&#039;potirons*&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux descendants de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;.  De m&ecirc;me, {Products hierarchy=&#039;*potirons&#039;} affiche un sommaire de tous les potirons, et des produits appartenant aux parents de l&#039;&eacute;l&eacute;ment de hi&eacute;rarchie &#039;potirons&#039;';
@@ -303,6 +318,7 @@ $lang['product_detail_settings'] = 'Param&egrave;tres D&eacute;tails du produit'
 $lang['product_editing_settings'] = 'Param&egrave;tres d&#039;&eacute;dition de produit';
 $lang['product_summary_settings'] = 'Param&egrave;tres des listes de produits';
 $lang['product_hierarchy'] = 'Hierarchie de produits';
+$lang['product_info'] = 'Information produit';
 $lang['product_manager'] = 'Gestionnaire de produits';
 $lang['progress'] = 'Progression';
 $lang['prompt'] = 'Libell&eacute;';
@@ -346,6 +362,7 @@ $lang['prompt_hierpage'] = 'Page par d&eacute;faut pour la vue de hi&eacute;rarc
 $lang['prompt_prettyhierurls'] = 'Utiliser les Urls r&eacute;&eacute;crites pour les vues de hi&eacute;rarchie ';
 $lang['prompt_prod_detailpage'] = 'Page par d&eacute;faut pour voir le d&eacute;tail des produits ';
 $lang['prompt_products_matching'] = 'Produits correspondant &agrave; %s';
+$lang['prompt_sku_required'] = 'Le SKU (UGS - Unit&eacute; de gestion des stocks) est requis pour tous les produits et attributs';
 $lang['prompt_summarypagelimit'] = 'Nombre de produits par d&eacute;faut et par page en mode Sommaire ';
 $lang['prompt_summarysortorder'] = 'Ordre de tri par d&eacute;faut en mode sommaire ';
 $lang['prompt_summarysorting'] = 'Champ de tri par d&eacute;faut en mode sommaire ';
@@ -357,7 +374,9 @@ $lang['prompt_usehierpathurls'] = 'Utiliser le chemin de hi&eacute;rarchie dans
 $lang['prompt_weightunits'] = 'Unit&eacute;s de poids';
 $lang['public'] = 'Est-ce un champ public ?';
 $lang['published'] = 'Publi&eacute;';
+$lang['quantity_on_hand'] = 'Quantit&eacute; en stock';
 $lang['random'] = 'Au hasard';
+$lang['reorder_hierarchy'] = 'R&eacute;ordonner la hi&eacute;rarchie';
 $lang['resettofactory'] = 'R&eacute;initialiser aux valeurs par d&eacute;faut';
 $lang['return'] = 'Retour';
 $lang['return_to_top'] = 'Retour en haut de page';
@@ -368,7 +387,10 @@ $lang['search_name'] = 'Nom de produit';
 $lang['search_price'] = 'Gamme de prix';
 $lang['searchtemplate_addedit'] = 'Ajouter/Modifier le gabarit de formulaire de recherche';
 $lang['searchtemplates'] = 'Gabarit de recherche';
+$lang['select_all'] = 'Tout s&eacute;lectionner';
 $lang['select_one'] = 'Choisir...';
+$lang['setdraft'] = 'D&eacute;finir &agrave; Brouillon';
+$lang['setpublished'] = 'D&eacute;finir &agrave; Publi&eacute;';
 $lang['sku'] = 'SKU (identifiant de quantit&eacute; en stock)';
 $lang['sort_by'] = 'Tri par';
 $lang['sort_order'] = 'Ordre de tri';
@@ -409,10 +431,10 @@ $lang['view'] = 'Vue';
 $lang['viewable_fields'] = 'S&eacute;lectionner les champs personnalis&eacute;s &agrave; afficher dans la liste';
 $lang['watermark_location'] = 'Emplacement du filigrane';
 $lang['weight'] = 'Poids';
+$lang['with_selected'] = 'Produits s&eacute;lectionn&eacute;s';
 $lang['yes'] = 'Oui';
-$lang['utmz'] = '156861353.1300521323.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-2066415722-1300533676093';
-$lang['utma'] = '156861353.1283075913.1300521323.1301054358.1301063008.14';
+$lang['utma'] = '156861353.206568057.1317628053.1317628053.1317628053.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1317628053.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
