@@ -38,10 +38,12 @@ $lang['categoryexists'] = 'Una categoria con quel nome gi&agrave; esiste';
 $lang['categorylisttemplates'] = 'Modelli Lista categorie';
 $lang['categorylisttemplate_addedit'] = 'Aggiungere/Modifica un Modello ListaCategorie';
 $lang['centimeters'] = 'Centimetri';
-$lang['checkbox'] = 'Checkbox';
+$lang['checkbox'] = 'Checkbox ';
+$lang['confirm_copyattributes'] = 'Tutti l&#039;insieme di attributi per questo prodotto sar&agrave; rimosso. Siete sicuro di voler continuare?';
 $lang['confirm_delete_hierarchy_node'] = 'Siete sicuro di voler proprio cancellare questo nodo? Tutti i prodotti che stanno usando questo nodo non saranno pi&ugrave; gerarchici';
 $lang['confirm_import'] = 'Siete veramente sicuri di voler fare questo?\n\nConfigurazioni non corrette o un file di configurazione non valido potrebbero corrompere il sistema.';
 $lang['copy'] = 'Copia';
+$lang['copy_attrib_sets'] = 'Copia l&#039;insieme degli Attributi';
 $lang['copy_category'] = 'Copia Categoria';
 $lang['createddate'] = 'Data di creazione';
 $lang['current_value'] = 'Valore corrente';
@@ -54,11 +56,13 @@ $lang['delete_attribset'] = 'Cancella attributo';
 $lang['delete_hierarchy_item'] = 'Cancella un Item gerarchico';
 $lang['descending'] = 'Discendente';
 $lang['description'] = 'Descrizione';
+$lang['destination'] = 'Destinazione';
 $lang['details'] = 'Dettagli';
 $lang['detailtemplates'] = 'Modelli Dettaglio';
 $lang['detailtemplate_addedit'] = 'Aggiungere/Modifica un Modello Dettaglio';
 $lang['dimensions'] = 'Dimensioni';
 $lang['disabled'] = 'Disabilitato';
+$lang['down'] = 'Muovi gi&ugrave;';
 $lang['draft'] = 'Bozza';
 $lang['dropdown'] = 'Tendina';
 $lang['dropdown_options'] = 'Opzioni Tendina <em>(applicabile solo per campi dropdown)</em><br/><br/><em>(un termine per ogni riga)</em>';
@@ -78,6 +82,7 @@ $lang['error_filenotfound'] = 'File non trovato';
 $lang['error_fileopen'] = 'Problema nell&#039;apertura del File %s';
 $lang['error_invalidparent'] = 'Parent invalido (un nodo gerarchico non pu&ograve; essere il proprio parent)';
 $lang['error_invalid_name'] = 'Il valore del campo personalizzato non &egrave; valido (contiene caratteri non alfanumerici)';
+$lang['error_invalid_value'] = 'Value specificato non valido';
 $lang['error_missingparam'] = 'Un parametro richiesto &egrave; mancante o non valido';
 $lang['error_nameused'] = 'Un item con quel nome &egrave; gi&agrave; in uso';
 $lang['error_nofieldtype'] = 'Si prega si selezionare il tipo di campo';
@@ -156,6 +161,7 @@ $lang['help'] = '<h3>What does this do?</h3>
 </ul>';
 $lang['hierarchy'] = 'Gerarchia';
 $lang['hierarchy_position'] = 'Posizione gerarchia';
+$lang['hierarchy_settings'] = 'Configurazioni della Gerarchia';
 $lang['id'] = 'ID';
 $lang['imagetext'] = 'Immagine';
 $lang['image_handling_settings'] = 'Configurazione Immagini';
@@ -164,9 +170,11 @@ $lang['inches'] = 'Pollici';
 $lang['include_children'] = 'Includo Figli?';
 $lang['info_alnumonly'] = 'Solo caratteri alfanumerici. No spazi, virgolette, apici o combinazioni lettere/numeri';
 $lang['info_attribtemplate'] = 'Valori possibili sono: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
+$lang['info_attributes_copied'] = 'Attributi Copiati';
 $lang['info_autowatermark'] = 'Configurazione dei Watermark sono prese dal modulo CGExtensions';
 $lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
 $lang['info_cart_module_params'] = 'Questi parametri sono dati al modulo Carrello selezionato dal dettaglio prodotti e visualizzazione sommario';
+$lang['info_copy_attribsets'] = 'Questa azione copier&agrave; l&#039;insieme degli Attributi (escludendo i valori sku) da un altro prodotto.';
 $lang['info_createfields'] = 'Creo automaticamente campi prodotti senza nome? <em>(Saranno creati come campi testo)</em>';
 $lang['info_createcategories'] = 'Automaticamente creo categorie produtto che coincidono con quelle del file CSV, se non esistono ancora';
 $lang['info_createhierarchy'] = 'Automaticamente creo gerarchie produtto che coincidono con quelle del file CSV, se non esistono ancora';
@@ -176,8 +184,10 @@ $lang['info_duplicateproducts'] = 'Specifica come il sistema dovrebbe tenere un
 $lang['info_fielddefs_tab'] = '<strong>Nota:</strong> Tutti i Campi qua definiti sono utilizzabili per tutti i prodotti.';
 $lang['info_fieldproblems'] = 'Problema con uno o pi&ugrave; dei campi personalizzati. L&#039;azione ha terminato con successo, tuttavia voi dovreste investigare e correggere questi problemi';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
+$lang['info_hierpage'] = 'Usa questa pagina per la visualizzazione gerarchica.  Il pageid non sar&agrave; specificato nell&#039;URL.';
 $lang['info_imagepath'] = 'Il path (relativo alla directory di uploads) dove le immagini, riferite al file di importazione, possono essere trovate';
 $lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
+$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Valori validi sono +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Campi pubblici sono utilizzabili per il pubblico da vedere';
@@ -196,7 +206,7 @@ $lang['name'] = 'Nome';
 $lang['needpermission'] = 'Non avete i permessi richiesti: %s';
 $lang['new_category_name'] = 'Nuovo nome Categoria';
 $lang['nextpage'] = '>';
-$lang['no'] = 'No';
+$lang['no'] = 'No ';
 $lang['nonamegiven'] = 'Nessun nome inserito';
 $lang['none'] = 'Nessuno';
 $lang['of'] = 'di';
@@ -221,7 +231,7 @@ $lang['param_categorylisttemplate'] = 'Utile solo con l&#039;azione categorylist
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'Questo specifica il ID di pagina o alias che dovrebbe essere usato per visualizzare il report dettaglio.';
 $lang['param_detailtemplate'] = 'Questo parametro specifica il Modello che dovrebbe essere usato per la visualizzazione dettaglio. Se nessun valore &egrave; specificato, allora sar&agrave; usato il Modello predefinito del tipo corrente.';
-$lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
+$lang['param_field'] = 'Usato solo nel <em>fieldlist</em> questo parametro &egrave; richiesto per specificare il nome di un user defined property per creare una lista.';
 $lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Utile solo con l&#039;azione <em>default</em>, questo parametro specifica che soloi termini nella locazione gerarchica dovrebbero essere visualizzati. Caratteri wildcard possono essere usati cos&igrave; che voi potete specificare relazioni parent/figli. Per esempio {Products hierarchy=&#039;trucks*&#039;} crea un report sommario di tutti i trucks, incluso i figli nella gerarchia. Similmente, {Products hierarchy=&#039;*trucks&#039;} visualizza un report sommario di tutti i trucks e tutti i prodotti tenuti da ogni parent nella gerarchia.';
 $lang['param_hierarchytemplate'] = 'Questo parametro specifica il Modello che dovrebbe essere usato per la visualizzazione gerarchia. Se nessun valore &egrave; specificato, allora sar&agrave; usato il Modello predefinito di quel tipo.';
@@ -229,6 +239,7 @@ $lang['param_inline'] = 'Useful only with the search action, this parameter spec
 $lang['param_pagelimit'] = 'Utile solo con l&#039;azione <em>default</em>, questo parametro specifica quanti termini dovrebbero essere visualizzati su ciascuna pagina.';
 $lang['param_parent'] = 'Utile solo con l&#039;azione <em>gerarchia</em>, questo parametro specifica l&#039;id della gerarchia della locazione di partenza del report.';
 $lang['param_productid'] = 'Utile solo con l&#039;azione dettaglio, questo parametro indica il prodotto che dovrebbe essere utilizzato per la visualizzazione.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
@@ -265,10 +276,12 @@ $lang['product'] = 'Prodotto';
 $lang['productname'] = 'Nome Prodotto';
 $lang['products'] = 'Gestione Prodotto';
 $lang['product_detail_settings'] = 'Configurazioni dettaglio Prodotti';
+$lang['product_editing_settings'] = 'Product Editing Settings';
+$lang['product_summary_settings'] = 'Product Summary Settings';
 $lang['product_hierarchy'] = 'Gerarchia Prodotto';
 $lang['product_manager'] = 'Gestore Prodotto';
 $lang['progress'] = 'Avanzamento';
-$lang['prompt'] = 'Prompt';
+$lang['prompt'] = 'Prompt ';
 $lang['prompt_add_attribset'] = 'Aggiungere/Modifica Attributi';
 $lang['prompt_allowed_filetypes'] = 'Permettere l&#039;upload di files con queste estensioni (per campi tipo file)';
 $lang['prompt_allowed_imagetypes'] = 'Permettere l&#039;upload di immagini con queste estensioni  (per campi tipo immagine)';
@@ -305,8 +318,11 @@ $lang['prompt_notfound_301'] = 'Genera una redirezione 301';
 $lang['prompt_notfound_errormsg'] = 'Visualizza un messaggio di errore';
 $lang['prompt_notfound_msg'] = 'Messaggio di errore quando un prodotto non pu&ograve; essere trovato';
 $lang['prompt_notfound_page'] = 'Pagina per fare una redirezione permanente?';
+$lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
+$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
 $lang['prompt_prod_detailpage'] = 'Pagina predefinita per la Visualizzazione Dettaglio Produtto';
 $lang['prompt_products_matching'] = 'Prodotti che combaciano con %s';
+$lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
 $lang['prompt_summarysortorder'] = 'Ordine predefinito nel modo sommario';
 $lang['prompt_summarysorting'] = 'Campo dell&#039;ordine predefinito nel modo sommario';
 $lang['prompt_template'] = 'Modello sorgente';
@@ -317,7 +333,7 @@ $lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
 $lang['prompt_weightunits'] = 'Unit&agrave; di peso';
 $lang['public'] = 'E&#039; un campo pubblico?';
 $lang['published'] = 'Pubblicato';
-$lang['random'] = 'Random';
+$lang['random'] = 'Random ';
 $lang['resettofactory'] = 'Azzera ai valori iniziali';
 $lang['return'] = 'Ritorna';
 $lang['return_to_top'] = 'Ritorna all&#039;inizio';
@@ -329,9 +345,10 @@ $lang['search_price'] = 'Intervallo di prezzo';
 $lang['searchtemplate_addedit'] = 'Aggiuge/Modifica Modulo Search Template';
 $lang['searchtemplates'] = 'Template di Ricerca';
 $lang['select_one'] = 'Seleziona uno';
-$lang['sku'] = 'SKU';
+$lang['sku'] = 'SKU ';
 $lang['sort_by'] = 'Ordine per';
 $lang['sort_order'] = 'Tipo ordine';
+$lang['source'] = 'Sorgente';
 $lang['status'] = 'Stato';
 $lang['submit'] = 'Invio';
 $lang['subscription'] = 'Sottoscrizione';
@@ -341,7 +358,7 @@ $lang['subscr_monthly'] = 'Mensilmente';
 $lang['subscr_delperiod'] = 'Frequenza di distribuzione';
 $lang['subscr_delperiod2'] = 'Distribuzione';
 $lang['subscr_payperiod'] = 'Frequenza di pagamento';
-$lang['subscr_payperiod2'] = 'Paid';
+$lang['subscr_payperiod2'] = 'Pagamento';
 $lang['subscr_quarterly'] = 'Quadimestrale';
 $lang['subscr_semianually'] = 'Semestrale';
 $lang['subscr_yearly'] = 'Annuale';
@@ -357,6 +374,7 @@ $lang['title_detail_dflttemplate'] = 'Modello nuovo dettaglio predefinito';
 $lang['title_search_dflttemplate'] = 'Nuovo Search Template predefinito';
 $lang['title_summary_dflttemplate'] = 'Modello nuovo sommario predefinito';
 $lang['type'] = 'Tipo';
+$lang['up'] = 'Muovi su';
 $lang['update'] = 'Aggiorna';
 $lang['upload'] = 'Seleziona un file per upload';
 $lang['url_alias'] = 'URL alias';
@@ -368,5 +386,8 @@ $lang['viewable_fields'] = 'Campi Select castomizzati per visualizzare in una ta
 $lang['watermark_location'] = 'Locazione del Watermark';
 $lang['weight'] = 'Peso';
 $lang['yes'] = 'S&igrave;';
-$lang['qca'] = 'P0-250679722-1271187168764';
+$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299074554.2';
+$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
