@@ -45,6 +45,7 @@ $lang['confirm_copyattributes'] = 'Eventuelle eksisterende attributtsett for det
 $lang['confirm_delete_hierarchy_node'] = 'Er du sikker p&aring; at du vil slette denne noden? Alle produkter som bruker denne noden vil bli satt til ingen hierarki';
 $lang['confirm_import'] = 'Er du helt sikker p&aring; at du vil gj&oslash;re dette?\n\nFeil innstillinger eller en ugyldig konfigurasjonsfil kan fullstendig &oslash;delegge et n&aring; gyldig og fungerende system.';
 $lang['copy'] = 'Kopier';
+$lang['copy_product'] = 'Kopier dette produktet';
 $lang['copy_attrib_sets'] = 'Kopier attributtsettene';
 $lang['copy_category'] = 'Kopier kategori';
 $lang['createddate'] = 'Opprettet dato';
@@ -76,7 +77,9 @@ $lang['edit_attributes'] = 'Rediger attributter';
 $lang['edit_category'] = 'Rediger Kategori';
 $lang['edit_category_fields'] = 'Rediger Kategori felter';
 $lang['edit_hierarchy_item'] = 'Rediger hierarki artikkel';
+$lang['errors'] = 'Feil';
 $lang['error_attribset_exists'] = 'En attributt med det navnet eksisterer allerede';
+$lang['error_dberror'] = 'Databasefeil';
 $lang['error_duplicate_sku'] = 'Duplikat V.nr.(SKU) funnet';
 $lang['error_fieldvalue_empty'] = 'Feltverdien kan ikke v&aelig;re tom';
 $lang['error_fileformat'] = 'Filformat rpoblem';
@@ -103,6 +106,12 @@ $lang['exclude_categories'] = 'Ekskluder produkter i de valgte kategoriene fra r
 $lang['expire_six_months'] = 'Etter seks m&aring;neder';
 $lang['expire_one_year'] = 'Etter ett &aring;r';
 $lang['expire_two_year'] = 'Etter to &aring;r';
+$lang['export_to_csv'] = 'Eksport til CSV';
+$lang['exportattribs'] = 'Eksport atributter';
+$lang['exportcats'] = 'Eksport kategorier';
+$lang['exportdelim'] = 'Eksport feltskilletegn';
+$lang['exportdraft'] = 'Eksport kladd produkter';
+$lang['exportfields'] = 'Eksport egendefinerte felter';
 $lang['extra1'] = 'Ekstrafelt 1';
 $lang['extra2'] = 'Ekstrafelt 2';
 $lang['field'] = 'Felt';
@@ -110,91 +119,12 @@ $lang['fields'] = 'Felter';
 $lang['fielddef'] = 'Feltdefinisjon';
 $lang['fielddefs'] = 'Feltdefinisjoner';
 $lang['file'] = 'Fil';
+$lang['filter'] = 'Filter ';
+$lang['filterinuse'] = 'aktivert';
 $lang['filters'] = 'Filtre';
 $lang['firstpage'] = '<< ';
 $lang['general_settings'] = 'Generelle innstillinger';
 $lang['go'] = 'Start';
-$lang['help'] = '<h3>What does this do?</h3>
-<p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is &#039;taxable&#039; or not.</p>
-  <p>This module provides multiple custom field definitions, and for the ability to discriminate private from public data.</p>
-<h3>Features:</h3>
-<ul>
-  <li>Numerous Views</li>
-    <ul>
-      <li>Summary view</li>
-      <li>Category List View</li>
-      <li>Detail view</li> 
-      <li>Hierarchy Drill-down View</li>
-    </ul>
-  <li>Entirely Database Template Driven</li>
-  <p>Numerous templates of each type can be defined, defaults specified for each type, and the template used for each particular view can be specified as a parameter</p>
-  <li>Sorting and pagination in the summary view</li>
-  <li>Products can exist in multiple categories</li>
-  <li>Numerous custom fields can be defined, including images</li>
-  <li>Automatic thumbnail creation</li>
-  <li>Admin defined fields</li>
-  <li>Product attributes (including price adjustment)</li>
-  <li>Weight and taxable fields (for use in e-commerce solutions)</li>
-  <li>Products can have a status (published or draft) in order to hide products from public display at any time</li>
-  <li>Pretty URL Support</li>
-  <li><strong>More...</strong></li>
-</ul>
-
-<h3>How Do I Use It:</h3>
-<ul>
-<li>Set preferences</li>
-<p>Usually this is just a formality.  You should specify your default weight units, and your default currency symbol for your local environment.</p>
-<li>Setup users and permissions</li>
-<p>This module uses the &#039;Modify Templates&#039; permission to allow users to be able to modify the various templates that can be used by this module.  As well, the &#039;Modify Site Preferences&#039; permission is needed to be able to adjust the modules preferences.  In order to have the ability to modify field definitions, categories, or products, your users will need the &#039;Modify Products&#039; permission.</p>
-<li>(optional) Define one or more categories</li>
-<p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the &#039;Categories&#039; tab in the Product Managers admin section, and clicking &#039;Add A Category&#039;.  From there you will be prompted for a category name.</p>
-<li>(optional) Define one or more custom fields</li>
-<p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
-<p>Currently a number of types of custom fields are available, including: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea&#039;, &#039;dropdown&#039;, and &#039;file&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
-<li>Create one or more products</li>
-<p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can also specify if the product is taxable.</p>
-<p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
-<p>If custom fields are defined, then input fields appropriate to the type of custom field will appear and allow you to specify data for each of them.  This data is optional.</p>
-<li>Add the appropriate tags into your page templates or page content</li>
-<p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
-<p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category=&#039;categoryname&#039;}</code></p>
-</ul>
-<h3>Smarty Plugins</h3>
-<p>This module also registers one or more smarty plugins to aide in retrieving various products related information when designing products module templates:</p>
-<ul>
-  <li>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}
-  <p>This plugin allows retrieving all of the information for a specific category id and optionally assigning it to the named smarty variable.  The returned is an object containing all of the information about a category, including its field values.<br/>i.e:. <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
-   
-   </p>
-  </li>
-</ul>
-<h3>Support</h3>
-<p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
-<ul>
-<li>For the latest version of this module, FAQs or to file a bug report, please visit the cms made simple <a href="http://dev.cmsmadesimple.org">Developers Forge</a> and do a search for &#039;Products&#039;</li>
-<li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
-<li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>
-<h3>Copyright and License</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarki';
 $lang['hierarchy_position'] = 'Hierarki posisjon';
 $lang['hierarchy_settings'] = 'Hierarki innstillinger';
@@ -211,6 +141,9 @@ $lang['info_autowatermark'] = 'Vannmerke innstillingene er hentet fra CGExtensio
 $lang['info_batchsize'] = 'Sett et antall linjer som skal prosesseres per &quot;batch&quot;. Etter hver batch er ferdig, vil importereren omdirigere, og fortsette operasjonene. Om du opplever minne feil eller tidsavbrudd problemer p&aring; grunn av store mengder i prosessering, so b&oslash;r du kanskje kontakte din din nettstedsvert, eller redusere dette antallet';
 $lang['info_cart_module_params'] = 'Disse parametere gis til den valgte handlekurv(cart) modulen fra produkt-detalj og -sammendragsvisningene';
 $lang['info_copy_attribsets'] = 'Denne handlingen vil kopiere attributtsett (unntatt sku verdier) fra et annet produkt.';
+$lang['info_clearattribs'] = 'Gjelder bare n&aring;r du oppdaterer eksisterende produkter, dette vil fjerne all attributt informasjon fra databasen for produkter f&oslash;r oppretting av nye';
+$lang['info_clearcategories'] = 'Gjelder bare n&aring;r du oppdaterer eksisterende produkter, vil dette fjerne alle kategori medlemskap f&oslash;r nye opprettes';
+$lang['info_clearfields'] = 'Gjelder bare n&aring;r du oppdaterer eksisterende produkter, vil dette fjerne alle felt f&oslash;r nye feltverdier opprettes';
 $lang['info_createfields'] = 'Opprett ukjente produktfelter automatisk? <em>(De vil bli opprettet som tekstfelter)</em>';
 $lang['info_createcategories'] = 'Opprett automatisk produktkategorier for &aring; samsvare med de som er i CSV filen, om de ikke allerede eksisterer';
 $lang['info_createhierarchy'] = 'Opprett produkthierarkier automatisk for &aring; samsvare med de som er i CSV filen, om de ikke allerede eksisterer';
@@ -233,6 +166,7 @@ $lang['info_setecomhandlers'] = 'Denne knappen vil sikre at hendelsesbehandlerne
 $lang['label'] = 'Etikett';
 $lang['label_skip'] = 'Hopp over';
 $lang['label_overwrite'] = 'Overskriv';
+$lang['label_update'] = 'Oppdater';
 $lang['lastpage'] = ' >>';
 $lang['last_modified'] = 'Sist endret';
 $lang['logotext'] = 'Andre bilde';
@@ -242,6 +176,7 @@ $lang['module_description'] = 'En modul for &aring; behandle en katalog med prod
 $lang['move_down'] = 'Flytt ned';
 $lang['move_up'] = 'Flytt opp';
 $lang['msg_eventhandlers_created'] = 'Hendelsesbehandlere opprettet';
+$lang['msg_productcopied'] = 'Produktet ble kopiert. Du redigerer n&aring; kopien. Enhver sku/varenummer informasjon i produktet, og/eller attributter er fjernet';
 $lang['name'] = 'Navn';
 $lang['needpermission'] = 'Du har ikke den n&oslash;dvendige rettigheten: %s';
 $lang['new_category_name'] = 'Nytt kategori navn';
@@ -268,6 +203,7 @@ $lang['param_action'] = 'Specify the behaviour of the module.  Possible values a
      </p>
   </li>
   <li>search - Display a form to allow searching products on various criterium</li>
+<li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
 </ul>';
 $lang['param_category'] = 'N&aring;r benyttet med <em>standard</em> sammendragsmodus vil denne parameter, som skal v&aelig;re lik navnet p&aring; en eksisterende kategori, bli benyttet for &aring; vise kun de produktene som er i denne kategorien. (en kommaseparert liste kan oppgis) Denne parameteren kan ogs&aring; benyttes med categorylist handlingen for &aring; begrense utdata til de spesifiserte produktkatagoriene.';
 $lang['param_categoryfield'] = 'Gjelder kun til &quot;categorylist&quot; handling, hvor denne parameteren kan brukes til &aring; filtrere kategorier basert p&aring; verdien av et kategorifelt. Dette vil ikke fungere i forbindelse med &quot;kategori&quot; eller &quot;category_id&quot; parametere. Syntaksen for denne parameteren er en kommaseparert liste med feltnavn, og feltverdier. dvs.: categorylist=&amp;quot;feltnavnet:verdi,feltnavn2:verdien 2&amp;quot;';
@@ -276,13 +212,17 @@ $lang['param_categorylistdtltemplate'] = 'Kan kun benyttes med categorylist hand
 $lang['param_detailpage'] = 'Dette spesifiserer sideid&#039;en eller sidealias som skal benyttes for &aring; vise detaljrapporten. Dette kan benyttes med <em>default</em> eller s&oslash;k handlingene.';
 $lang['param_detailtemplate'] = 'Denne parameter spesifiserer malen som skal benyttes for detaljmodus visning. Om ingen verdi er oppgitt vil n&aring;v&aelig;rende standard mal av denne type bli benyttet. Denne parameter har ingen virkning n&aring;r vakre urler er p&aring;sl&aring;tt.';
 $lang['param_excludecat'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren vil tillate unntak av produkter som er i en bestemt kategori fra resultatet. En kommaseparert liste med kategorinavn er tillatt. Denne parameteren kan fungere sammen med kategori-parameteren for &aring; gi en liste over produkter som er i denne kategorien, men ikke i den kategorien';
-$lang['param_field'] = 'Benyttet kun i <em>fieldlist</em> handlingen, der denne parameter er p&aring;krevd for &aring; spesifisere navnet p&aring; en brukerdefinert egenskap som det skal lages en liste fra.';
-$lang['param_fieldval'] = 'Kun benyttet i <em>standard</em> handlinge, hvor denne parameter tillater &aring; spesifisere en feltverdi &aring; begrense resultater etter. Spesialverdier for dette feltet er &quot;::null::&quot; &quot;::notnull::&quot;';
+$lang['param_field'] = '
+Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the product name, sku and alias respectively.';
+$lang['param_fieldval'] = '
+Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b.';
 $lang['param_hierarchy'] = 'Kan kun benyttes i <em>default</em> og hierarki handlinger. Denne parameter har to oppgaver - den spesifiserer at kun artikler i denne lokasjonen i hierarkiet skal vises.  Jokertegn kan benyttes s&aring; du ogs&aring; kan spesifisere foreldre/barn relasjoner. F.eks. {Products hierarchy=&#039;trucks*&#039;} vil lage en sammendragsrapport med alle trucks, inkludert barna i hierarkiet.  P&aring; samme m&aring;te, {Products hierarchy=&#039;*trucks&#039;} vil vise en sammendragsrapport med alle trucks og alle produkter tilh&oslash;rende enhver foreldre i hierarkiet. N&aring;r benyttet med hierarkihandlingen s&aring; kan denne parameter gi en liste med hierarkinavn for &aring; vise akkurat disse. F.eks. {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;}';
 $lang['param_hierarchytemplate'] = 'Denne parameter spesifiserer malen som skal brukes for hierarki visning. Om ingen verdi er satt vil standard mal av den typen bli benyttet.';
 $lang['param_inline'] = 'Kun nyttig for s&oslash;k-handlingen, der denne parameteren spesifiserer at utdata for sammendragesvisningen skal vises inline';
+$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
 $lang['param_pagelimit'] = 'Benyttet med <em>standard</em> handlingen vil denne parameter spesifisere hvor mange produkter som skal listes p&aring; hver side.';
 $lang['param_parent'] = 'Kan kun benyttes i <em>hierarchy</em> handlingen. Denne parameter spesifiserer hierarki id til start posisjonen i rapporten.';
+$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
 $lang['param_productid'] = 'Benyttet med detalj handlingen vil denne parameter indikere hvilket produkt som skal vises p&aring; siden.';
 $lang['param_productlist'] = 'Gjelder kun til standard (sammendrag) visning, hvor denne parameteren kan angi en kommaseparert liste med heltall produkt-IDer &aring; vise. Ingen paginering eller sortering utf&oslash;res da p&aring; disse verdiene. Andre spesifiserte filtreringsparametere, om dette er spesifisert for sammendragsvisningen, vil ogs&aring; ignoreres.';
 $lang['param_resultpage'] = 'Kun gyldig for s&oslash;k handlingen, hvor denne parameteren spesifiserer en side-id eller alias &aring; benytte for &aring; vise s&oslash;keresultatene';
@@ -321,6 +261,7 @@ $lang['preferences'] = 'Preferanser';
 $lang['preuninstall'] = '&Aring; fjerne denne modulen vil ogs&aring; fjerne alle assosierte data, er du sikker p&aring; at du vil fortsette?';
 $lang['price'] = 'Pris';
 $lang['price_adjustment'] = 'Prisjustering';
+$lang['prefix_copyof'] = 'Kopi av ';
 $lang['prevpage'] = '< ';
 $lang['product'] = 'Produkt';
 $lang['productname'] = 'Produktnavn';
@@ -346,6 +287,9 @@ $lang['prompt_applicable'] = 'Sl&aring; p&aring; som standard for alle nye produ
 $lang['prompt_batchsize'] = 'Batch st&oslash;rrelse';
 $lang['prompt_cart_module'] = 'Handlekurv(cart) modul';
 $lang['prompt_cart_module_params'] = 'Handlekurv(cart) modul parametere';
+$lang['prompt_clearattribs'] = 'Rens attributter ved oppdatering';
+$lang['prompt_clearcategories'] = 'Rens kategorier ved oppdatering';
+$lang['prompt_clearfields'] = 'Rens felter ved oppdatering';
 $lang['prompt_createcategories'] = 'Opprett kategorier';
 $lang['prompt_createfields'] = 'Opprett produktkategorier?';
 $lang['prompt_createhierarchy'] = 'Opprett produktkategori';
@@ -374,6 +318,7 @@ $lang['prompt_prettyhierurls'] = 'Benytt vakre URLer for hierarkivisningene';
 $lang['prompt_prod_detailpage'] = 'Standardside for Product detaljvisning';
 $lang['prompt_products_matching'] = 'Produkter som passer %s';
 $lang['prompt_sku_required'] = 'V.nr.(SKU) er p&aring;krevd for alle produkter og attributter';
+$lang['prompt_summary_newdefault'] = 'Benytt ny samendragsvisning';
 $lang['prompt_summarypagelimit'] = 'Standard sidegrense i sammendragsmodus';
 $lang['prompt_summarysortorder'] = 'Standard sortering i sammendragsmodus';
 $lang['prompt_summarysorting'] = 'Standard sorteringsfelt i sammendragsmodus';
@@ -388,6 +333,7 @@ $lang['published'] = 'Publisert';
 $lang['quantity_on_hand'] = 'Mengde tilgjengelig';
 $lang['random'] = 'Tilfeldig';
 $lang['reorder_hierarchy'] = 'Omorganiser hierarki';
+$lang['reset'] = 'Nullstill';
 $lang['resettofactory'] = 'Sett tilbake til fabrikkinnstillinger';
 $lang['return'] = 'Tilbake';
 $lang['return_to_top'] = 'Returner til toppen av visningen';
@@ -445,8 +391,8 @@ $lang['weight'] = 'Vekt';
 $lang['with_selected'] = 'Med valgte';
 $lang['yes'] = 'Ja';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.771487945.1315514710.1315743680.1315755952.10';
-$lang['utmz'] = '156861353.1315514710.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1400698784.1339530996.1339878866.1339882165.16';
+$lang['utmz'] = '156861353.1339530996.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.2.10.1315755952';
 ?>
\ No newline at end of file
