@@ -45,6 +45,7 @@ $lang['confirm_copyattributes'] = 'Eventuele bestaande attributen voor dit produ
 $lang['confirm_delete_hierarchy_node'] = 'Bent u zeker dat u deze node wilt verwijderen?  Elk product wat gebruik maakt van deze node zal niet meer onder een hi&euml;rarchie vallen.';
 $lang['confirm_import'] = 'Bent u zeker dat u dit wilt uitvoeren?\n\nVerkeerde instellingen of een verkeerd configuratiebestand kan het hele systeem in de war brengen. Wat resulteert in een niet werkende producten module.';
 $lang['copy'] = 'Kopie';
+$lang['copy_product'] = 'Kopieer dit item';
 $lang['copy_attrib_sets'] = 'Kopieer attributenset';
 $lang['copy_category'] = 'Categorie kopieren';
 $lang['createddate'] = 'Aangemaakt op';
@@ -76,7 +77,9 @@ $lang['edit_attributes'] = 'Attribuut aanpassen';
 $lang['edit_category'] = 'Categorie aanpassen';
 $lang['edit_category_fields'] = 'Categorie Velden aanpassen';
 $lang['edit_hierarchy_item'] = 'Hierarchie Item aanpassen';
+$lang['errors'] = 'Fouten';
 $lang['error_attribset_exists'] = 'Er bestaat al een attribuut met deze naam';
+$lang['error_dberror'] = 'Database fout';
 $lang['error_duplicate_sku'] = 'Dubbele Uitlevereenheid waarde gevonden';
 $lang['error_fieldvalue_empty'] = 'De Veld Waarde mag niet leeg zijn';
 $lang['error_fileformat'] = 'File Format probleem';
@@ -103,6 +106,12 @@ $lang['exclude_categories'] = 'Sluit producten in de geselecteerde categori&euml
 $lang['expire_six_months'] = 'Na zes maanden';
 $lang['expire_one_year'] = 'Na een jaar';
 $lang['expire_two_year'] = 'Na twee jaar';
+$lang['export_to_csv'] = 'Export naar CSV';
+$lang['exportattribs'] = 'Export Attributen';
+$lang['exportcats'] = 'Export Categori&euml;n';
+$lang['exportdelim'] = 'Export field Delimiter';
+$lang['exportdraft'] = 'Export Draft Items';
+$lang['exportfields'] = 'Export Custom Fields';
 $lang['extra1'] = 'Extra veld 1';
 $lang['extra2'] = 'Extra veld 2';
 $lang['field'] = 'Veld';
@@ -110,91 +119,12 @@ $lang['fields'] = 'Velden';
 $lang['fielddef'] = 'Velddefinitie';
 $lang['fielddefs'] = 'Velddefinities';
 $lang['file'] = 'Bestand';
+$lang['filter'] = 'Filter ';
+$lang['filterinuse'] = 'in werking';
 $lang['filters'] = 'Filters ';
 $lang['firstpage'] = '<<';
 $lang['general_settings'] = 'Algemene instellingen';
 $lang['go'] = 'Ga naar';
-$lang['help'] = '<h3>What does this do? </h3>
-<p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is &#039;taxable&#039; or not.</p>
-  <p>This module provides for up to two images per product, custom field definitions, and for the ability to descriminate private from public data.</p>
-<h3>Features:</h3>
-<ul>
-  <li>Numerous Views</li>
-    <ul>
-      <li>Summary view</li>
-      <li>Category List View</li>
-      <li>Detail view</li> 
-      <li>Hierarchy Drill-down View</li>
-    </ul>
-  <li>Entirely Database Template Driven</li>
-  <p>Numerous templates of each type can be defined, defaults specified for each type, and the template used for each particular view can be specified as a parameter</p>
-  <li>Sorting and pagination in the summary view</li>
-  <li>Products can exist in multiple categories</li>
-  <li>Numerous custom fields can be defined, including images</li>
-  <li>Automatic thumbnail creation</li>
-  <li>Admin defined fields</li>
-  <li>Product attributes (including price adjustment)</li>
-  <li>Weight and taxable fields (for use in e-commerce solutions)</li>
-  <li>Products can have a status (published or draft) in order to hide products from public display at any time</li>
-  <li>Pretty URL Support</li>
-  <li><strong>More...</strong></li>
-</ul>
-
-<h3>How Do I Use It:</h3>
-<ul>
-<li>Set preferences</li>
-<p>Usually this is just a formality.  You should specify your default weight units, and your default currency symbol for your local environment.</p>
-<li>Setup users and permissions</li>
-<p>This module uses the &#039;Modify Templates&#039; permission to allow users to be able to modify the various templates that can be used by this module.  As well, the &#039;Modify Site Preferences&#039; permission is needed to be able to adjust the modules preferences.  In order to have the ability to modify field definitions, categories, or products, your users will need the &#039;Modify Products&#039; permission.</p>
-<li>(optional) Define one or more categories</li>
-<p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the &#039;Categories&#039; tab in the Product Managers admin section, and clicking &#039;Add A Category&#039;.  From there you will be prompted for a category name.</p>
-<li>(optional) Define one or more custom fields</li>
-<p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
-<p>Currently six types of custom fields are available: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea, dropdown, and file&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
-<li>Create one or more products</li>
-<p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can also specify if the product is taxable.</p>
-<p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
-<p>If custom fields are defined, then input fields appropriate to the type of custom field will appear and allow you to specify data for each of them.  This data is optional.</p>
-<li>Add the appropriate tags into your page templates or page content</li>
-<p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
-<p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category=&#039;categoryname&#039;}</code></p>
-</ul>
-<h3>Smarty Plugins</h3>
-<p>This module also registers one or more smarty plugins to aide in retrieving various products related information when designing products module templates:</p>
-<ul>
-  <li>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}
-  <p>This plugin allows retrieving all of the information for a specific category id and optionally assigning it to the named smarty variable.  The returned is an object containing all of the information about a category, including its field values.<br/>i.e:. <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
-   
-   </p>
-  </li>
-</ul>
-<h3>Support</h3>
-<p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
-<ul>
-<li>For the latest version of this module, FAQs or to file a bug report, please visit the cms made simple <a href="http://dev.cmsmadesimple.org">Developers Forge</a> and do a search for &#039;Products&#039;</li>
-<li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
-<li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>
-<h3>Copyright and License</h3>
-<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
-<p>This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.</p>
-<p>However, as a special exception to the GPL, this software is distributed
-as an addon module to CMS Made Simple.  You may not use this software
-in any Non GPL version of CMS Made simple, or in any version of CMS
-Made simple that does not indicate clearly and obviously in its admin 
-section that the site was built with CMS Made simple.</p>
-<p>This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarchie';
 $lang['hierarchy_position'] = 'Hierarchie Positie';
 $lang['hierarchy_settings'] = 'Hierachie instellingen';
@@ -211,6 +141,9 @@ $lang['info_autowatermark'] = 'De watermerk instellingen zijn afkomstig uit de C
 $lang['info_batchsize'] = 'Stel het aantal regels om uit te voeren per &#039;batch&#039; in. Nadat een batch is voltooid, zal de importer worden doorverwezen en doorgaan met de operatie. Als u verwacht dat er mogelijk geheugenfouten gaan ontstaan of time-outproblemen door het hoge aantal regels per keer, dan kunt u beter contact opnemen met uw hostingprovider of dit nummer lager instellen.';
 $lang['info_cart_module_params'] = 'Deze parameters worden doorgegeven aan de geselecteerde cart module vanuit het  product uitgebreid en opsomming displays';
 $lang['info_copy_attribsets'] = 'Deze actie zal de attributensets kopie&euml;ren (exclusief sku waardes) van een ander product';
+$lang['info_clearattribs'] = 'Only applicable when updating existing items, this will clear all attribute information from the database for items before creating new ones';
+$lang['info_clearcategories'] = 'Only applicable when updating existing items, this will clear all category memberships befoe creating new ones';
+$lang['info_clearfields'] = 'Only applicable when updating existing items, this will clear all fields befoe creating field values';
 $lang['info_createfields'] = 'Maak onbekende productvelden automatisch aan? <em>(Ze worden dan aangemaakt als tekstveld)</em>';
 $lang['info_createcategories'] = 'Maak automatisch een productcategorie aan die voorkomt in het CSV file als deze nog niet bestaat';
 $lang['info_createhierarchy'] = 'Maak automatisch een product hi&euml;rarchie aan die voorkomt in het CSV file als deze nog niet bestaan';
@@ -233,6 +166,7 @@ $lang['info_setecomhandlers'] = 'Deze knop garandeert dat de gebeurtenissen voor
 $lang['label'] = 'Label ';
 $lang['label_skip'] = 'Sla over';
 $lang['label_overwrite'] = 'Overschrijven';
+$lang['label_update'] = 'Bijwerken';
 $lang['lastpage'] = '>>';
 $lang['last_modified'] = 'Laatst aangepast op';
 $lang['logotext'] = 'Tweede Afbeelding';
@@ -242,6 +176,7 @@ $lang['module_description'] = 'Een module voor het managen van een productcatalo
 $lang['move_down'] = 'Verschuif naar beneden';
 $lang['move_up'] = 'Verschuif naar boven';
 $lang['msg_eventhandlers_created'] = 'Gebeurtenishandlers gecree&euml;rd.';
+$lang['msg_productcopied'] = 'Item successfully copied.  You are now editing the copy.  Any sku information in the item, and/or attributes has been cleared';
 $lang['name'] = 'Naam';
 $lang['needpermission'] = 'U heeft niet de vereiste rechten: %s';
 $lang['new_category_name'] = 'Nieuwe Categorie Naam';
@@ -256,34 +191,50 @@ $lang['operation_complete'] = 'Operatie uitgevoerd';
 $lang['page'] = 'Pagina';
 $lang['page_of'] = 'Pagina %s van %s';
 $lang['page_limit'] = 'Pagina Limiet';
-$lang['param_action'] = 'Specificeer de werking van de module.  Mogelijke waarden zijn:
+$lang['param_action'] = '
+
+Specify the behaviour of the module.  Possible values are:
 <ul>
-  <li>hierarchy -- Toon een productlijst op basis van hi&euml;rarchie</li>
-  <li>categorylist - Toon een productlijst op basis van categorien</li>
-  <li><em>default</em> - Display a summary of products</li>
-  <li>details - Display a detail view of a single product</li>
-<li>fieldlist - Display a list of values from a specified field.
+  <li>hierarchy -- Display an item list by hierarchy</li>
+  <li>categorylist - Display a list of item categories</li>
+  <li><em>default</em> - Display a summary of items</li>
+  <li>details - Display a detail view of a single item</li>
+  <li>fieldlist - Display a list of values from a specified field.
      <p>
 &nbsp;&nbsp;&nbsp;&nbsp;- This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &amp;quot;color&amp;quot; and then create a navigation based on the different colors.
      </p>
   </li>
-  <li>search - Display a form to allow searching products on various criterium</li>
+  <li>search - Display a form to allow searching items on various criterium</li>
+<li>ajax_propval - Return a json encoded list of property values matching the criteria specified.  This action is intended to be used via ajax, and should be called with the showtemplate=false parameter on the URL.</li>
+</ul> ';
+$lang['param_category'] = '
 
-</ul>';
-$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
+When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those items that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified item categories. ';
 $lang['param_categoryfield'] = 'Alleen van toepassing op de &quot;categorylist&quot; actie, deze parameter kan gebruikt worden om categori&euml;n te filteren op basis van de waarde van het categorieveld. Het werkt niet in combinatie met de &quot;category&quot; of de &quot;category_id&quot; parameters. De syntax van deze parameter is een kommagescheiden lijst met veldnamen en veldwaarden.  Bijvoorbeeld:  categorylist=&quot;veldnaam:waarde,veldnaam 2:waarde 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used. ';
-$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
-$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
+$lang['param_detailpage'] = '
+
+This specifies the pageid or alias that should be used to display the detail report.  It can be used with the <em>default</em> or search actions.  This option is not compatible with pretty urls of any sort. ';
+$lang['param_detailtemplate'] = '
+
+This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.  This parameter has no use when pretty urls are enabled. ';
 $lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category ';
-$lang['param_field'] = 'Used only in the <em>fieldlist</em> action, this parameter is required to specify the name of a user defined property to create a list from.';
-$lang['param_fieldval'] = 'Alleen voor de <em>standaard</em> actie, deze parameter staat toe een waarde op te geven om de resultaten bij te limiteren.  Speciale waarden voor dit veld zijn: &quot;::null::&quot; &quot;::notnull::&quot;';
-$lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
+$lang['param_field'] = '
+
+Used in the <em>fieldlist</em> and the <em>ajax_propval</em> actions. In the fieldlist action, this parameter is required to specify the name of a user defined property to create a list from.  In the ajax_propval action this parameter is used to specify which field to use to extract a list of values.  Any valid field names are accepted (though only text field and dropdown field names will work properly.  Additionally the special values ::name::, ::sku::, and ::alias:: can be specified to return values from the item name, sku and alias respectively. ';
+$lang['param_fieldval'] = '
+
+Used in the <em>default</em> and <em>ajax_propval</em> actions, this parameter allows specifying a field value to limit results by.  In the default value these special values are accepted: &amp;quot;::null::&amp;quot; &amp;quot;::notnull::&amp;quot;. In the ajax_propval action this field is expected to contain only a few letters, to indicate a small filter.  i.e: fieldval=b to return all field values that begin with the letter b. ';
+$lang['param_hierarchy'] = '
+
+Useed in the <em>default</em> and hierachy actions this parameter has two uses.  When used in the default (summary) action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all items beloging to any parent in the hierarchy.  A comma separated list of expressions can be supplied.  i.e: {Products action=hierarchy hierarchy=&#039;trucks,cars&#039;} ';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used. ';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline ';
+$lang['param_notpretty'] = 'Thie parameter specifies a comma separated list of actions to which pretty urls should not be generated.  i.e: notpretty=hierarchy,default will not generate pretty urls to hierarchy, or summary (default) actions, but will allow generation of pretty urls to detail views.  As a special vaue &quot;all&quot; can be used to specify that no pretty urls should be generated';
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report. ';
+$lang['param_parents'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies a comma separated list of hierarchy names that specify to create numerous heirarchy trees from the specified location(s).  Hierarchy names must be unique, and not contain any special chars.';
 $lang['param_productid'] = 'Heeft alleen zin in de uitgebreide sjabloon. Deze parameter geeft aan welk product te gebruiken bij het weergeven.';
 $lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored. ';
 $lang['param_resultpage'] = 'Applicable only to the search action, this parameter specifies a page id or alias to use to display the search results';
@@ -295,18 +246,25 @@ $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.
   <li><strong>asc</strong> -- Ascending order</li>
   <li>desc -- Descending order</li>
 </ul>';
-$lang['param_sortby'] = 'Applicable only in the summary or search actions, this parameter determines the sorting of the output products.  Possible values are: 
+$lang['param_sortby'] = '
+
+Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
 <ul>
-  <li><strong>product_name</strong></li>
-  <li>id -- The product id</li>
-  <li>weight -- The product weight</li>
-  <li>price -- The product base price</li>
+  <li><strong>item_name</strong></li>
+  <li>id -- The item id</li>
+  <li>weight -- The item weight</li>
+  <li>price -- The item base price</li>
   <li>status -- Draft or published</li>
   <li>random -- Display in random order on each request</li>
   <li>created -- The creation date for this company record</li>
   <li>modified -- The modified date for this company record</li>
   <li>f:fieldname -- Allows sorting by values of custom fields.</li>
-</ul>';
+</ul>
+<p>The category list view supports only a few specific sorting options:</p>
+<ul>
+  <li>id -- The category id.</li>
+  <li><strong>name</strong> -- The category name.</li>
+</ul> ';
 $lang['param_sorttype'] = 'Alleen van toepassing op de standaard samenvattingsweergave, deze parameter kan worden gebruikt om waardes om te zetten naar een ander type voor sortering.  Geldige waarden zijn STRING, SIGNED en UNSIGNED. Als dit niet is opgegeven dan zal standaard STRING worden gekozen.';
 $lang['param_summarypage'] = 'Alleen van toepassing op action=hierarchy, staat toe op een pagina id of alias op te geven die moet worden gebruikt voor de links in de samenvattingsweergave.';
 $lang['param_summarytemplate'] = 'Deze parameter geeft aan welke opsomming sjabloon er gebruikt moet worden. Als er geen geselecteerd wordt dan word de standaard sjabloon gebruikt.';
@@ -317,6 +275,7 @@ $lang['preferences'] = 'Voorkeuren';
 $lang['preuninstall'] = 'Als de module wordt verwijderd dan word ook alle aanwezige data gewist. Bent u zeker dat u wilt verdergaan?';
 $lang['price'] = 'Prijs';
 $lang['price_adjustment'] = 'Prijswijziging';
+$lang['prefix_copyof'] = 'Kopieer van';
 $lang['prevpage'] = '<';
 $lang['product'] = 'Product ';
 $lang['productname'] = 'Productnaam';
@@ -342,6 +301,9 @@ $lang['prompt_applicable'] = 'Schakel standaard in voor alle nieuwe producten';
 $lang['prompt_batchsize'] = 'Volume grootte';
 $lang['prompt_cart_module'] = 'Cart Module ';
 $lang['prompt_cart_module_params'] = 'Cart Module Parameters ';
+$lang['prompt_clearattribs'] = 'Clear attributes on update';
+$lang['prompt_clearcategories'] = 'Clear categories on update';
+$lang['prompt_clearfields'] = 'Clear fields on update';
 $lang['prompt_createcategories'] = 'Maak categori&euml;n';
 $lang['prompt_createfields'] = 'Maak product velden?';
 $lang['prompt_createhierarchy'] = 'Maak product hi&euml;rarchie';
@@ -370,6 +332,7 @@ $lang['prompt_prettyhierurls'] = 'Gebruik Pretty URL&#039;s voor de hie&auml;rch
 $lang['prompt_prod_detailpage'] = 'Standaard Pagina voor Product Detail Overzichten';
 $lang['prompt_products_matching'] = 'Producten gelijk aan %s';
 $lang['prompt_sku_required'] = 'Een SKU is vereist voor alle producten en attributen';
+$lang['prompt_summary_newdefault'] = 'Use new summary view';
 $lang['prompt_summarypagelimit'] = 'Standaard paginalimiet in samenvattingsmodus';
 $lang['prompt_summarysortorder'] = 'Standaard sorteervolgorde in samenvattingsmodus';
 $lang['prompt_summarysorting'] = 'Standaard veldvolgorde in samenvattingsmodus';
@@ -384,6 +347,7 @@ $lang['published'] = 'Gepubliceerd';
 $lang['quantity_on_hand'] = 'Beschikbare hoeveelheid';
 $lang['random'] = 'Willekeurig';
 $lang['reorder_hierarchy'] = 'Herorder hierarchie';
+$lang['reset'] = 'Reset ';
 $lang['resettofactory'] = 'Reset naar standaardinstellingen';
 $lang['return'] = 'Keer terug';
 $lang['return_to_top'] = 'Ga terug naar de bovenkant van de pagina';
@@ -440,9 +404,8 @@ $lang['watermark_location'] = 'Plaats Watermerk';
 $lang['weight'] = 'Gewicht';
 $lang['with_selected'] = 'Met geselecteerden';
 $lang['yes'] = 'Ja';
-$lang['utma'] = '156861353.826990304.1314695841.1314696054.1314715138.3';
-$lang['utmz'] = '156861353.1314695841.1.1.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['qca'] = 'P0-856617467-1310370352588';
+$lang['utma'] = '156861353.345096645.1341849918.1341849918.1341849918.1';
+$lang['utmz'] = '156861353.1341849918.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
