@@ -12,6 +12,7 @@ $lang['add_category_field'] = 'Przypisać pole do kategorii: &quot;%s&quot;';
 $lang['add_hierarchy_item'] = 'Dodaj element hierarchii';
 $lang['add_option'] = 'Dodaj opcję atrybutu';
 $lang['admin_only'] = 'Czy tylko administratorzy mogą widzieć ten atrybut?';
+$lang['advanced'] = 'Zaawansowane';
 $lang['align_ul'] = 'G&oacute;rny lewy';
 $lang['align_uc'] = 'G&oacute;rny środek';
 $lang['align_ur'] = 'G&oacute;rny prawy';
@@ -29,6 +30,7 @@ $lang['areyousure_deleteproduct'] = 'Czy napewno chcesz usunąć ten produkt ora
 $lang['ascending'] = 'Rosnąco';
 $lang['attribute_name'] = 'Nazwa atrybutu';
 $lang['automatic'] = 'Automatycznie';
+$lang['btn_setecomhandlers'] = 'Set Ecommerce Event Handlers';
 $lang['byhierarchytemplates'] = 'Szablony raport&oacute;w hierarchii';
 $lang['byhierarchytemplate_addedit'] = 'Dodaj/Edytuj szablon raportu hierarchii';
 $lang['cancel'] = 'Anuluj';
@@ -39,9 +41,11 @@ $lang['categorylisttemplates'] = 'Szablony listy kategorii';
 $lang['categorylisttemplate_addedit'] = 'Dodaj/Edytuj szablon listy kategorii';
 $lang['centimeters'] = 'Centymetry';
 $lang['checkbox'] = 'Checkbox';
+$lang['confirm_copyattributes'] = 'Any existing attribute sets for this product will be removed. Are you sure you want to continue?';
 $lang['confirm_delete_hierarchy_node'] = 'Czy napewno chcesz usunąć ten element hierarchii? Wszystkie produkty używające tego elementu nie będą przypisane do żadnej hierarchii';
 $lang['confirm_import'] = 'Are you sure you really want to do this?\n\nImproper settings, or an invalid config file could completely corrupt a currently valid and working system.';
 $lang['copy'] = 'Skopiuj';
+$lang['copy_attrib_sets'] = 'Copy Attribute Sets';
 $lang['copy_category'] = 'Skopiuj kategorię';
 $lang['createddate'] = 'Data utworzenia';
 $lang['current_value'] = 'Aktualna wartość';
@@ -54,11 +58,13 @@ $lang['delete_attribset'] = 'Skasuj atrybut';
 $lang['delete_hierarchy_item'] = 'Skasuj element hierarchii';
 $lang['descending'] = 'Malejąco';
 $lang['description'] = 'Opis';
+$lang['destination'] = 'Destination';
 $lang['details'] = 'Szczeg&oacute;ły';
 $lang['detailtemplates'] = 'Szablony szczeg&oacute;łowe';
 $lang['detailtemplate_addedit'] = 'Dodaj/edytuj szablon szczeg&oacute;łowy';
 $lang['dimensions'] = 'Wymiary';
 $lang['disabled'] = 'Wyłączony';
+$lang['down'] = 'Przesuń w d&oacute;ł';
 $lang['draft'] = 'Kopia robocza';
 $lang['dropdown'] = 'Lista rozwijalna';
 $lang['dropdown_options'] = 'Opcjelisty rozwijalnej <em>(ato pole jest używane tylko przy listach rozwijalnych)</em><br/><br/><em>(jedna linia to jedna opcja)</em>';
@@ -71,31 +77,36 @@ $lang['edit_category'] = 'Edytuj kategorię';
 $lang['edit_category_fields'] = 'Edytuj pola kategorii';
 $lang['edit_hierarchy_item'] = 'Edytuj element hierarchii';
 $lang['error_attribset_exists'] = 'Atrybut z taką nazwą już istnieje';
-$lang['error_duplicate_sku'] = 'Duplicate SKU value found';
+$lang['error_duplicate_sku'] = 'Znaleziono zduplikowaną wartość SKU';
 $lang['error_fieldvalue_empty'] = 'Wartość pola nie może być pusta';
 $lang['error_fileformat'] = 'Problem z formatem pliku';
 $lang['error_filenotfound'] = 'Nie odnaleziono pliku';
-$lang['error_fileopen'] = 'Problem opening file %s';
+$lang['error_fileopen'] = 'Problem podczas otwierania pliku %s';
 $lang['error_invalidparent'] = 'Nieprawidłowy element nadrzędny (gałąź hierarchii nie może być swoim własnym elementem nadrzędnym)';
 $lang['error_invalid_name'] = 'Wartość pola jest niepoprawna (może zawierać tylko znaki alfanumeryczne)';
+$lang['error_invalid_value'] = 'Invalid value specified';
 $lang['error_missingparam'] = 'WYmagany parametr jest nieprawidłowy lub pusty';
 $lang['error_nameused'] = 'Element z taką nazwą już istnieje';
 $lang['error_nofieldtype'] = 'Proszę wybraćtyp pola';
 $lang['error_noname'] = 'Musisz wpisać nazwę';
+$lang['error_onequantityfield'] = 'Only one quantity field is allowed';
 $lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
-$lang['error_permissiondenied'] = 'Permission Denied';
-$lang['error_product_aliasused'] = 'The alias specified is already in use';
+$lang['error_permissiondenied'] = 'Dostęp zabroniony';
+$lang['error_product_aliasused'] = 'Określony alias jest już użyty';
 $lang['error_product_nameused'] = 'Produkt z taką nazwą już istnieje';
 $lang['error_product_notfound'] = 'The requested product could not be found';
-$lang['error_product_skuused'] = 'That SKU value is already in use by another product';
-$lang['error_price_adjustment'] = 'NIeprawidłowa zmiana wartości ceny dla elementu %s';
+$lang['error_product_skuused'] = 'Ta wartość SKU jest już przypisana innemu produktowi';
+$lang['error_price_adjustment'] = 'Nieprawidłowa zmiana wartości ceny dla elementu %s';
+$lang['error_sku_required'] = 'Wpisz unikalne SKU';
 $lang['error_upload_failed'] = 'Załadowanie pliku nie powiodło się: %s';
-$lang['expire_six_months'] = 'After Six Months';
-$lang['expire_one_year'] = 'After One Year';
-$lang['expire_two_year'] = 'After Two Years';
-$lang['extra1'] = 'Extra Field 1';
-$lang['extra2'] = 'Extra Field 2';
+$lang['exclude_categories'] = 'Exclude products in the selected categories from the results';
+$lang['expire_six_months'] = 'Po sześciu miesiącach';
+$lang['expire_one_year'] = 'Po roku';
+$lang['expire_two_year'] = 'Po dw&oacute;ch latach';
+$lang['extra1'] = 'Pole Extra 1';
+$lang['extra2'] = 'Pole Extra 2';
 $lang['field'] = 'Pole';
+$lang['fields'] = 'Pola';
 $lang['fielddef'] = 'Definicja pola';
 $lang['fielddefs'] = 'Definicje p&oacute;l';
 $lang['file'] = 'Plik';
@@ -105,7 +116,7 @@ $lang['general_settings'] = 'Ustawienia';
 $lang['go'] = 'Go';
 $lang['help'] = '<h3>What does this do?</h3>
 <p>This module provides a way to collect, organize, and display information about products and their categories.  This module can stand on its own, or be part of an e-commerce solution if you wish.  The module supports a product existing in more than one category, supports product weight, price, and attribute sets.  Each item in an attribute set can have a price adjustment.  Also a global flag indicates wether the product is &#039;taxable&#039; or not.</p>
-  <p>This module provides for up to two images per product, custom field definitions, and for the ability to descriminate private from public data.</p>
+  <p>This module provides multiple custom field definitions, and for the ability to discriminate private from public data.</p>
 <h3>Features:</h3>
 <ul>
   <li>Numerous Views</li>
@@ -139,7 +150,7 @@ $lang['help'] = '<h3>What does this do?</h3>
 <p>This is an optional step, but you will probably want to do this early to prevent having to go back to modify each and every product later.  Adding a category is as simple as clicking on the &#039;Categories&#039; tab in the Product Managers admin section, and clicking &#039;Add A Category&#039;.  From there you will be prompted for a category name.</p>
 <li>(optional) Define one or more custom fields</li>
 <p>This is an optional step.  Custom fields are not needed if this module suits you exactly as it is.  However if you would like to store additional information for each of your products you can create custom fields.  Creating custom fields is similar to creating categories, except that more data is requested.</p>
-<p>Currently six types of custom fields are available: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea, dropdown, and file&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
+<p>Currently a number of types of custom fields are available, including: &#039;textbox&#039;,&#039;checkbox&#039;,and &#039;textarea&#039;, &#039;dropdown&#039;, and &#039;file&#039;.  Select one of these, give your new field a name, and indicate wether that field should be visible to the public in the various views.  Then hit submit</p>
 <li>Create one or more products</li>
 <p>You should create one or more products to display in your website content.  Give each product a name, a price (optional) a weight (optional), a status (draft or published), and some information.  Additionally, you can also specify if the product is taxable.</p>
 <p>If categories are defined, then a checkbox will appear for each defined category.  You can simply click the checkbox fields for each category that this product should belong to.</p>
@@ -148,6 +159,15 @@ $lang['help'] = '<h3>What does this do?</h3>
 <p>This can be as simple as adding the <strong>{Products}</strong> tag into the content area of one of your pages, or into your page template.</p>
 <p>If you wish to alter the behaviour of this application from its default, you can do that by adding one or more parameters to the <strong>{Products}</strong> tag.  The complete list of parameters and their behaviour is listed below.  But for example, to display a list of products in a single, existing category, you could use a tag like <code>{Products category=&#039;categoryname&#039;}</code></p>
 </ul>
+<h3>Smarty Plugins</h3>
+<p>This module also registers one or more smarty plugins to aide in retrieving various products related information when designing products module templates:</p>
+<ul>
+  <li>{products_getcategory categoryid=&#039;99&#039; [assign=&#039;tmp&#039;]}
+  <p>This plugin allows retrieving all of the information for a specific category id and optionally assigning it to the named smarty variable.  The returned is an object containing all of the information about a category, including its field values.<br/>i.e:. <code>{products_getcategory categoryid=1 assign=&#039;tmp&#039;}Category name = {$tmp->name}</code></p>
+   
+   </p>
+  </li>
+</ul>
 <h3>Support</h3>
 <p>This module does not include commercial support.  However there are a number of resources available to help you with it:</p>
 <ul>
@@ -155,20 +175,42 @@ $lang['help'] = '<h3>What does this do?</h3>
 <li>To obtain commercial support, please send an email to the author at <a href="mailto:calguy1000@cmsmadesimple.org">Robert Campbell</a>.</li>
 <li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forms.</a></li>
 <li>For some questions and limited technical support, the author can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
-</ul>';
+</ul>
+<h3>Copyright and License</h3>
+<p>Copyright &amp;copy; 2008, Robert Campbel <a href="mailto:calguy1000@cmsmadesimple.org">&amp;lt;calguy1000@cmsmadesimple.org&amp;gt;</a>. All Rights Are Reserved.</p>
+<p>This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.</p>
+<p>However, as a special exception to the GPL, this software is distributed
+as an addon module to CMS Made Simple.  You may not use this software
+in any Non GPL version of CMS Made simple, or in any version of CMS
+Made simple that does not indicate clearly and obviously in its admin 
+section that the site was built with CMS Made simple.</p>
+<p>This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
 $lang['hierarchy'] = 'Hierarchia';
 $lang['hierarchy_position'] = 'Pozycja w hierarchii';
+$lang['hierarchy_settings'] = 'Ustawienia hierarchii';
 $lang['id'] = 'ID';
 $lang['imagetext'] = 'Obrazek';
-$lang['image_handling_settings'] = 'Image Handling Settings';
-$lang['import_from_csv'] = 'Import Products from CSV file';
+$lang['image_handling_settings'] = 'Ustawienia obsługi obrazk&oacute;w';
+$lang['import_from_csv'] = 'Zaimportuj Produkty z pliku CSV';
 $lang['inches'] = 'Cale';
 $lang['include_children'] = 'Dołączyć elementy podrzędne?';
 $lang['info_alnumonly'] = 'Tylko znaki alfanumeryczne (bez spacji, apostrof&oacute;w, cudzysłow&oacute;w, polskich znak&oacute;w)';
-$lang['info_attribtemplate'] = 'Possible variables are: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
+$lang['info_attribtemplate'] = 'Możliwe wartości to: {$attrib_text},{$attrib_adjust},{$currency_symbol}';
+$lang['info_attributes_copied'] = 'Atrybuty skopiowane';
 $lang['info_autowatermark'] = 'Ustawienia znak&oacute;w wodnych są pobierane z modułu CGExtensions';
 $lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
 $lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the product detail and summary displays';
+$lang['info_copy_attribsets'] = 'This action will copy Attribute sets (excluding sku values) from another product.';
 $lang['info_createfields'] = 'Create unknown product fields automatically? <em>(They will be created as text fields)</em>';
 $lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
 $lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
@@ -178,11 +220,16 @@ $lang['info_duplicateproducts'] = 'Specify how the system should handle a produc
 $lang['info_fielddefs_tab'] = '<strong>Uwaga: </strong> Wszystkie pola zdefiniowane tutaj są dostępne dla wszystkich produkt&oacute;w.';
 $lang['info_fieldproblems'] = 'Wystąpiły problemy z obsługą jednego lub więcej p&oacute;l zdefiniowanych. Akcja została przeprowadzona poprawnie, jednak powinieneś sprawdzić czy wszystko jest w porządku';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
+$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
 $lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
+$lang['info_imagestuff_deprecated'] = 'Konwertowanie obrazk&oacute;w jest przestarzałe i zostanie usunięte w nowszych wersjach. Użyj CGSmartImage dla konwertowania obrazk&oacute;w w locie.';
 $lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
+$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Poprawne wartości pola to +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Pola publiczne są widoczne dla wszystkich';
+$lang['info_reorder_content'] = 'This operation allows dragging the individual nodes in the tree to adjust the order that they will be displayed in in the hierarchy view';
+$lang['info_setecomhandlers'] = 'This button will ensure that event handlers for ecommerce events are in place.  This is useful if asking the products module to keep track of a quantity on hand, but the event handlers did not get created during install or upgrade';
 $lang['label'] = 'Etykieta';
 $lang['label_skip'] = 'Pomiń';
 $lang['label_overwrite'] = 'Nadpisz';
@@ -192,8 +239,9 @@ $lang['logotext'] = 'Drugi obrazek';
 $lang['maxlength'] = 'Maksymalna długość <em>(dotyczy tylko p&oacute;l tekstowych)</em>';
 $lang['modifieddate'] = 'Data modyfikacji';
 $lang['module_description'] = 'Moduł pozwalający na stworzenie katalogu produkt&oacute;w z cenami, zdjęciami itp. Pozwala także na tworzenie koszyka.';
-$lang['move_down'] = 'Move Down';
-$lang['move_up'] = 'Move Up';
+$lang['move_down'] = 'Przesuń w d&oacute;ł';
+$lang['move_up'] = 'Przesuń w g&oacute;rę';
+$lang['msg_eventhandlers_created'] = 'Obsługa zdarzeń stworzona';
 $lang['name'] = 'Nazwa';
 $lang['needpermission'] = 'Nie posiadasz wymaganego uprawnienia: %s';
 $lang['new_category_name'] = 'Nowa nazwa kategorii';
@@ -201,30 +249,42 @@ $lang['nextpage'] = '>';
 $lang['no'] = 'Nie';
 $lang['nonamegiven'] = 'Nie podano nazwy';
 $lang['none'] = 'Brak';
+$lang['nothing_selectd'] = 'Nic nie zaznaczono';
 $lang['of'] = 'z';
+$lang['operation_cancelled'] = 'Operacja anulowana';
+$lang['operation_complete'] = 'Operacja zakończona';
 $lang['page'] = 'Strona';
 $lang['page_of'] = 'Strona %s z %s';
 $lang['page_limit'] = 'Limit na stronę';
-$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
+$lang['param_action'] = 'SSpecify the behaviour of the module.  Possible values are:
 <ul>
   <li>hierarchy -- Display a product list by hierarchy</li>
   <li>categorylist - Display a list of product categories</li>
   <li><em>default</em> - Display a summary of products</li>
-  <li>detail - Display a detail view of a single product</li>
+  <li>details - Display a detail view of a single product</li>
+  <li>fieldlist - Display a list of values from a specified field.
+     <p>
+&nbsp;&nbsp;&nbsp;&nbsp;- This action can be used to create a navigation from the values of a specific field.  i.e:  you could create a custom dropdown field called &amp;quot;color&amp;quot; and then create a navigation based on the different colors.
+     </p>
+  </li>
+  <li>search - Display a form to allow searching products on various criterium</li>
 </ul>';
-$lang['param_category'] = 'Kiedy użyty w trybie <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
+$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied).  This parameter can also be used with the categorylist action to limit the output to the specified product categories.';
+$lang['param_categoryfield'] = 'Applicable only to the &quot;categorylist&quot; action, this parameter can be used to filter categories based on the value of a category field.  It will not work in conjunction with the &quot;category&quot; or &quot;category_id&quot; parameters.   The syntax of this parameter is a comma separated list of field names, and field values.  i.e:  categorylist=&quot;field name:value,field name 2:value 2&quot;';
 $lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
 $lang['param_categorylistdtltemplate'] = 'Useful only with the categorylist actions, this parameter indicates the template that should be used for the display of the category details.  This uses a category list template..  If no value is specified then the current default template of that type is used.';
 $lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
 $lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
+$lang['param_excludecat'] = 'Applicable only to the default (summary) view, this parameter will allow excluding products that are in a specific category from the result. A comma separated list of category names is allowed. This parameter can work in conjunction with the category parameter to provide a list of the products that are in this category, but not in that category';
 $lang['param_field'] = 'Used only in the <em>fieldlist</em> this parameter is required to specify the name of a user defined property to create a list from.';
 $lang['param_fieldval'] = 'Used only in the <em>default</em> action, this parameter allows specifying a field value to limit results by.  Special values for this field are &quot;::null::&quot; &quot;::notnull::&quot;';
 $lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
 $lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
 $lang['param_inline'] = 'Useful only with the search action, this parameter specifies that the output of the summary view should be displayed inline';
-$lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
+$lang['param_pagelimit'] = 'Useful only with the <em>default</em> or search actions, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
 $lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what product to use for the display.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
@@ -234,14 +294,22 @@ $lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.
   <li><strong>asc</strong> -- Ascending order</li>
   <li>desc -- Descending order</li>
 </ul>';
-$lang['param_sortby'] = 'Applicable only in summary mode, this parameter determines the sorting of the output products.  Possible values are:
+$lang['param_sortby'] = 'Applicable in the summary, categorylist or search actions, this parameter determines the sorting of the output.  Possible values are:
 <ul>
   <li><strong>product_name</strong></li>
+  <li>id -- The product id</li>
+  <li>weight -- The product weight</li>
   <li>price -- The product base price</li>
   <li>status -- Draft or published</li>
   <li>random -- Display in random order on each request</li>
   <li>created -- The creation date for this company record</li>
   <li>modified -- The modified date for this company record</li>
+  <li>f:fieldname -- Allows sorting by values of custom fields.</li>
+</ul>
+<p>The category list view supports only a few specific sorting options:</p>
+<ul>
+  <li>id -- The category id.</li>
+  <li><strong>name</strong> -- The category name.</li>
 </ul>';
 $lang['param_sorttype'] = 'Applicable only to the default summary view, this parameter is used to convert the values to another type for sorting.  valid values are STRING,SIGNED and UNSIGNED.  If not supplied the default STRING type is assumed.';
 $lang['param_summarypage'] = 'Applicable only to the action=hierarchy, allows specifying a page id or alias that will be used for any links to summary view';
@@ -257,8 +325,11 @@ $lang['prevpage'] = '<';
 $lang['product'] = 'Produkt';
 $lang['productname'] = 'Nazwa produktu';
 $lang['products'] = 'Produkty';
-$lang['product_detail_settings'] = 'Product Detail Settings';
+$lang['product_detail_settings'] = 'Ustawienia szczeg&oacute;ł&oacute;w produkt&oacute;w';
+$lang['product_editing_settings'] = 'Ustawienia edycji produkt&oacute;w';
+$lang['product_summary_settings'] = 'Ustawienia widoku og&oacute;lnego';
 $lang['product_hierarchy'] = 'Hierarchia produkt&oacute;w';
+$lang['product_info'] = 'Informacje o produkcie';
 $lang['product_manager'] = 'Katalog produkt&oacute;w';
 $lang['progress'] = 'Progress';
 $lang['prompt'] = 'Zachęta';
@@ -267,9 +338,9 @@ $lang['prompt_allowed_filetypes'] = 'Pozw&oacute;l na upload plik&oacute;w tego
 $lang['prompt_allowed_imagetypes'] = 'Pozw&oacute;l na upload obrazk&oacute;w tego typu (dla p&oacute;l typu obrazek)';
 $lang['prompt_attribtemplate'] = 'Template for display of product attribute values in dropdown';
 $lang['prompt_autothumbnail'] = 'Tw&oacute;rz automatycznie miniatury obrazk&oacute;w';
-$lang['prompt_autothumbnail_size'] = 'Maximum size (largest dimension) of the thumbnail.';
-$lang['prompt_autopreviewimg'] = 'Automatically create preview images of images';
-$lang['prompt_autopreviewimg_size'] = 'Maximum size (largest dimension) of the preview image.';
+$lang['prompt_autothumbnail_size'] = 'Maksymalny rozmiar (najdłuższy bok) miniaturki.';
+$lang['prompt_autopreviewimg'] = 'Automatycznie tw&oacute;rz obrazki poglądowe';
+$lang['prompt_autopreviewimg_size'] = 'Maksymalny rozmiar (najdłuższy bok) obrazka poglądowego.';
 $lang['prompt_autowatermark'] = 'Automatycznie nakładaj znaki wodne na ładowane obrazki';
 $lang['prompt_applicable'] = 'Włącz domyślnie dla nowych produkt&oacute;w';
 $lang['prompt_batchsize'] = 'Batch Size';
@@ -278,41 +349,47 @@ $lang['prompt_cart_module_params'] = 'Cart Module Parameters';
 $lang['prompt_createcategories'] = 'Create Categories';
 $lang['prompt_createfields'] = 'Create Product Fields?';
 $lang['prompt_createhierarchy'] = 'Create Product Hierarchy';
-$lang['prompt_csvfile'] = 'Upload CSV File';
+$lang['prompt_csvfile'] = 'Wgraj plik CSV';
 $lang['prompt_currencycode'] = 'Kod waluty';
 $lang['prompt_currencysymbol'] = 'Symbol waluty';
-$lang['prompt_default_status'] = 'By default all new products have this status';
-$lang['prompt_default_taxable'] = 'By default all new products are taxable';
+$lang['prompt_default_status'] = 'Domyślny status wszystkich nowych produkt&oacute;w';
+$lang['prompt_default_taxable'] = 'Domyślnie wszystkie nowe produkty są opodatkowane';
 $lang['prompt_deleteproductfiles'] = 'Skasować wszystkie pliki związane z produktem gdy jest on kasowany?';
 $lang['prompt_delimiter'] = 'Field Delimiter';
-$lang['prompt_detailpage'] = 'DOmyślna strona widoku szczeg&oacute;łowego';
+$lang['prompt_detailpage'] = 'Domyślna strona widoku szczeg&oacute;łowego';
 $lang['prompt_detailsfor'] = 'Details for %s';
 $lang['prompt_duplicateproducts'] = 'How to handle duplicate products?';
-$lang['prompt_false'] = 'False';
+$lang['prompt_false'] = 'Fałsz';
 $lang['prompt_handleimages'] = 'Handle images?';
 $lang['prompt_imagepath'] = 'Image Path';
-$lang['prompt_lengthunits'] = 'Length Units';
-$lang['prompt_notfound_behavior'] = 'What action should be taken when a product cannot be displayed?';
-$lang['prompt_notfound_404'] = 'Generate a 404 error';
-$lang['prompt_notfound_301'] = 'Generate a 301 redirect';
-$lang['prompt_notfound_errormsg'] = 'Display an error message';
+$lang['prompt_lengthunits'] = 'Jednostki miary';
+$lang['prompt_notfound_behavior'] = 'Co zrobić, jeżeli produkt nie może zostać wyświetlony?';
+$lang['prompt_notfound_404'] = 'Generuj błąd 404';
+$lang['prompt_notfound_301'] = 'Generuj przekierowanie 301';
+$lang['prompt_notfound_errormsg'] = 'Wyświetl wiadomość o błędzie';
 $lang['prompt_notfound_msg'] = 'Error message for when a product cannot be found';
 $lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
+$lang['prompt_hierpage'] = 'Domyślna strona dla widoku hierarchii';
+$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
 $lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
 $lang['prompt_products_matching'] = 'Products matching %s';
+$lang['prompt_sku_required'] = 'SKU is required for all products and attributes';
+$lang['prompt_summarypagelimit'] = 'Domyślny limit stron w widoku podsumowania';
 $lang['prompt_summarysortorder'] = 'Domyślna kolejność sortowania w widoku listy';
 $lang['prompt_summarysorting'] = 'Domyślne pole używane do sortowania w widoku listy';
 $lang['prompt_template'] = 'Źr&oacute;dło szablonu';
-$lang['prompt_true'] = 'True';
+$lang['prompt_true'] = 'Prawda';
 $lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
 $lang['prompt_use_detailpage_for_search'] = 'Use this page for search results too <em>(overrides the searchresults page parameter in the search module)</em>';
 $lang['prompt_usehierpathurls'] = 'Use Hierarchy Path in Product Detail URLS';
 $lang['prompt_weightunits'] = 'Jednosti wagi';
 $lang['public'] = 'Czy to jest pole dostępne dla wszystkich?';
 $lang['published'] = 'Opublikowany';
+$lang['quantity_on_hand'] = 'Dostępna ilość w magazynie';
 $lang['random'] = 'Losowy';
+$lang['reorder_hierarchy'] = 'Zmień kolejność hierarchii';
 $lang['resettofactory'] = 'Przywr&oacute;ć wartości domyślne';
-$lang['return'] = 'Return';
+$lang['return'] = 'Powr&oacute;t';
 $lang['return_to_top'] = 'Return to the top of the view';
 $lang['root'] = 'Gł&oacute;wny';
 $lang['search_description'] = 'Search Property Description';
@@ -321,11 +398,15 @@ $lang['search_name'] = 'Search Property Name';
 $lang['search_price'] = 'Price Range';
 $lang['searchtemplate_addedit'] = 'Add/Edit Search Form Template';
 $lang['searchtemplates'] = 'Search Templates';
+$lang['select_all'] = 'Zaznacz wszystkie';
 $lang['select_one'] = 'Wybierz opcję';
-$lang['sku'] = 'SKU';
+$lang['setdraft'] = 'Ustaw jako kopia robocza';
+$lang['setpublished'] = 'Ustaw jako opublikowane';
+$lang['sku'] = 'SKU ';
 $lang['sort_by'] = 'Sortuj po';
 $lang['sort_order'] = 'Kolejność sortowania';
-$lang['status'] = 'Status';
+$lang['source'] = 'Source';
+$lang['status'] = 'Status ';
 $lang['submit'] = 'Zapisz';
 $lang['subscription'] = 'Subscription';
 $lang['subscr_expiry'] = 'Expiry';
@@ -347,12 +428,13 @@ $lang['textbox'] = 'Pole tekstowe';
 $lang['title_byhierarchy_dflttemplate'] = 'Domyślny nowy szablon raportu hierarchii';
 $lang['title_categorylist_dflttemplate'] = 'Domyślny nowy szablon listy kategorii';
 $lang['title_detail_dflttemplate'] = 'Domyślny nowy szablon widoku szczeg&oacute;łowego';
-$lang['title_search_dflttemplate'] = 'Default New Search Template';
+$lang['title_search_dflttemplate'] = 'Domyślny nowy szablon wyszukiwarki';
 $lang['title_summary_dflttemplate'] = 'Domyślny nowy szablon widoku listy';
 $lang['type'] = 'Typ';
+$lang['up'] = 'Przesuń do g&oacute;ry';
 $lang['update'] = 'Aktualizuj';
 $lang['upload'] = 'Wybierz plik';
-$lang['url_alias'] = 'URL Alias';
+$lang['url_alias'] = 'Alias URL';
 $lang['valid'] = 'Poprawny';
 $lang['value'] = 'Wartość';
 $lang['values'] = 'Wartości';
@@ -360,10 +442,8 @@ $lang['view'] = 'Zobacz';
 $lang['viewable_fields'] = 'Select custom fields to view in the table';
 $lang['watermark_location'] = 'Ścieżka do pliku ze znakiem wodnym';
 $lang['weight'] = 'Waga';
+$lang['with_selected'] = 'Zaznaczone';
 $lang['yes'] = 'Tak';
-$lang['utma'] = '156861353.130117701.1281030249.1283951162.1284039329.12';
-$lang['utmz'] = '156861353.1284039329.12.8.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/413|utmcmd=referral';
-$lang['qca'] = 'P0-1706049120-1281030249820';
-$lang['utmb'] = '156861353';
-$lang['utmc'] = '156861353';
+$lang['qca'] = 'P0-1318213739-1275668371303';
+$lang['utma'] = '156861353.1873496283.1294340762.1294340762.1294340762.1';
 ?>
\ No newline at end of file
