@@ -56,7 +56,7 @@ $lang['delete_attribset'] = 'Удалить атрибут';
 $lang['delete_hierarchy_item'] = 'Удалить Элемент Иерархии';
 $lang['descending'] = 'По убыванию';
 $lang['description'] = 'Описание';
-$lang['destination'] = 'Destination';
+$lang['destination'] = 'Назначение';
 $lang['details'] = 'Описание';
 $lang['detailtemplates'] = 'Шаблон Карточки товара';
 $lang['detailtemplate_addedit'] = 'Добавить/Редактировать шаблон карточки товара';
@@ -65,7 +65,7 @@ $lang['disabled'] = 'Отключено';
 $lang['down'] = 'Передвинуть вниз';
 $lang['draft'] = 'Черновик';
 $lang['dropdown'] = 'Выпадающий список';
-$lang['dropdown_options'] = 'Dropdown Options <em>(applicable only for dropdown fields)</em><br/><br/><em>(one entry per line)</em>';
+$lang['dropdown_options'] = 'Элементы выпадающего списка <em>(применимо только для полей типа "выпадающий список")</em><br/><br/><em>(все элементы в разных строках)</em>';
 $lang['edit'] = 'Редактировать';
 $lang['edit_attribset'] = 'Редактировать атрибут';
 $lang['edit_attribsets'] = 'Редактировать набор атрибутов';
@@ -74,24 +74,24 @@ $lang['edit_attributes'] = 'Редактировать атрибуты';
 $lang['edit_category'] = 'Редактировать категорию';
 $lang['edit_category_fields'] = 'Редактировать поля категории';
 $lang['edit_hierarchy_item'] = 'Редактировать элемент иерархии';
-$lang['error_attribset_exists'] = 'An attribute with that name already exists';
-$lang['error_duplicate_sku'] = 'Duplicate SKU value found';
+$lang['error_attribset_exists'] = 'Атрибут с этим именем уже существует';
+$lang['error_duplicate_sku'] = 'Дублируется значение SKU';
 $lang['error_fieldvalue_empty'] = 'Необходимо заполнить поле';
 $lang['error_fileformat'] = 'Ошибка формата файла';
 $lang['error_filenotfound'] = 'Файл не найден';
 $lang['error_fileopen'] = 'Не удалось открыть файл %s';
 $lang['error_invalidparent'] = 'Invalid Parent (a hierarchy node cannot be it\'s own parent)';
 $lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
-$lang['error_invalid_value'] = 'Invalid value specified';
-$lang['error_missingparam'] = 'A required parameter is missing or invalid';
-$lang['error_nameused'] = 'An item by that name is already in use';
-$lang['error_nofieldtype'] = 'Please select a field type';
-$lang['error_noname'] = 'You must supply a name';
+$lang['error_invalid_value'] = 'Указано неверное значение';
+$lang['error_missingparam'] = 'Обязательный параметр пропущен или указан неверно';
+$lang['error_nameused'] = 'Товар с таким названием уже существует';
+$lang['error_nofieldtype'] = 'Пожалуйста укажите тип поля';
+$lang['error_noname'] = 'Вы должны указать имя';
 $lang['error_onesubscriptionfield'] = 'Only one subscription field is allowed';
-$lang['error_permissiondenied'] = 'Permission Denied';
-$lang['error_product_aliasused'] = 'The alias specified is already in use';
-$lang['error_product_nameused'] = 'A product by that name already exists';
-$lang['error_product_notfound'] = 'The requested product could not be found';
+$lang['error_permissiondenied'] = 'Доступ запрещен';
+$lang['error_product_aliasused'] = 'Указаный алиас уже используется';
+$lang['error_product_nameused'] = 'Товар с таким названием уже существует';
+$lang['error_product_notfound'] = 'Запрашиваемый товар не найден';
 $lang['error_product_skuused'] = 'That SKU value is already in use by another product';
 $lang['error_price_adjustment'] = 'Invalid price adjustment value for item %s';
 $lang['error_upload_failed'] = 'Upload failed: %s';
@@ -163,7 +163,8 @@ $lang['help'] = '<h3>What does this do?</h3>
 </ul>';
 $lang['hierarchy'] = 'Иерархия';
 $lang['hierarchy_position'] = 'Позиция в иерархии';
-$lang['id'] = 'ID';
+$lang['hierarchy_settings'] = 'Hierarchy Settings';
+$lang['id'] = ' Код';
 $lang['imagetext'] = 'Изображение';
 $lang['image_handling_settings'] = 'Image Handling Settings';
 $lang['import_from_csv'] = 'Импорт продуктов из CSV файла';
@@ -185,14 +186,16 @@ $lang['info_duplicateproducts'] = 'Specify how the system should handle a produc
 $lang['info_fielddefs_tab'] = '<strong>Примечание: </strong> Все поля определяемые здесь доступны для всех товаров.';
 $lang['info_fieldproblems'] = 'Возникли проблемы при работе с одним или более пользовательских полей. действие завершено успешно, однако вы должны изучить и исправить эти проблемы.';
 $lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to "image"';
+$lang['info_hierpage'] = 'Use this page for hierarchy views.  The pageid will not be spefiried on the URL.';
 $lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
 $lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
+$lang['info_prettyhierurls'] = 'Include the hierarchy item name on the URL';
 $lang['info_price_adjustment'] = 'Допустимые значения +-*#.##';
 $lang['info_prodnotfound'] = 'This option determines the behaviour of the website if a product detail view is accessed directly by URL, and that product for whatever reason (disabled, deleted, etc) cannot be accessed.';
 $lang['info_publicfield'] = 'Публичные поля доступны для просмотра посетителями';
 $lang['label'] = 'Подпись';
 $lang['label_skip'] = 'Пропустить';
-$lang['label_overwrite'] = 'Overwrite';
+$lang['label_overwrite'] = 'Перезаписать';
 $lang['lastpage'] = '>>';
 $lang['last_modified'] = 'Изменен';
 $lang['logotext'] = 'Второе изображение';
@@ -232,6 +235,7 @@ $lang['param_inline'] = 'Useful only with the search action, this parameter spec
 $lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
 $lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
 $lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what product to use for the display.';
+$lang['param_productlist'] = 'Applicable only to the default (summary) view, this parameter allows specifying a comma separated list of integer product ids to display.  No pagination or sorting is performed on these values, and if specified the other filtering parameters to the summary view are ignored.';
 $lang['param_resultpage'] = 'Applicable only to the search, and category list actions, this parameter specifies a page id or alias to use to display the summary results';
 $lang['param_searchfield'] = 'Applicable only to the search action, this parameter may contain a comma separated list of field names to include in the search';
 $lang['param_searchformtemplate'] = 'Applicable only to the search action, thisparameter allows specifying a non default search form template';
@@ -309,6 +313,8 @@ $lang['prompt_notfound_301'] = 'Generate a 301 redirect';
 $lang['prompt_notfound_errormsg'] = 'Display an error message';
 $lang['prompt_notfound_msg'] = 'Error message for when a product cannot be found';
 $lang['prompt_notfound_page'] = 'Page to do permanent redirect to?';
+$lang['prompt_hierpage'] = 'Default Page for Hierarchy View';
+$lang['prompt_prettyhierurls'] = 'Use Pretty URLS to Hierarchy Views';
 $lang['prompt_prod_detailpage'] = 'Default Page for Product Detail Views';
 $lang['prompt_products_matching'] = 'Products matching %s';
 $lang['prompt_summarypagelimit'] = 'Default page limit in summary mode';
@@ -375,9 +381,9 @@ $lang['viewable_fields'] = 'Select custom fields to view in the table';
 $lang['watermark_location'] = 'Расположение водяных знаков(подписи на изображение)';
 $lang['weight'] = 'Вес';
 $lang['yes'] = 'Да';
-$lang['qca'] = 'P0-1938388883-1277855813144';
-$lang['utma'] = '156861353.429593658.1277855813.1295214078.1295220134.172';
-$lang['utmz'] = '156861353.1295194781.170.80.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
+$lang['utma'] = '156861353.1586252174.1302554112.1302554112.1302554112.1';
+$lang['utmb'] = '156861353.4.9.1302554623453';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1302554112.1.1.utmcsr=yandex|utmccn=(organic)|utmcmd=organic|utmctr=cms made simple';
+$lang['qca'] = 'P0-54757025-1302554112098';
 ?>
\ No newline at end of file
