@@ -37,9 +37,11 @@
 #-------------------------------------------------------------------------
 #END_LICENSE
 
-class product_utils
+final class product_utils
 {
   protected function __construct() {}
+  private static $_category_cache;
+  static private $_flddef_cache;
 
   static public function get_field_types($selectone = false)
   {
@@ -139,52 +141,22 @@ class product_utils
 
   static public function hierarchy_get_tree($parent_id = -1,$showall = 0,$callback_fn = '')
   {
-    global $gCms;
-    $db = $gCms->GetDb();
+    $hierarchy_map = hierarchy_ops::get_all_hierarchy_info(TRUE,$showall);
+    if( !is_array($hierarchy_map) || count($hierarchy_map) == 0 ) return FALSE;
 
-    $where = array();
-    $parms = array();
-
-    $where[] = 'ph.parent_id = ?';
-    $parms[] = $parent_id;
-    if( $showall )
-      {
-	$where[] = 'pr.status = ?';
-	$parms[] = 'published';
+    $out = array();
+    foreach( $hierarchy_map as $onehier ) {
+      if( $onehier['parent_id'] != $parent_id ) continue;
+      if( $callback_fn != '' && function_exists($callback_fn) ) {
+	$callback_fn($onehier);
       }
-
-    $query = 'SELECT ph.*,count(pr.id) AS count FROM '.cms_db_prefix().'module_products_hierarchy ph
-                LEFT OUTER JOIN '.cms_db_prefix().'module_products_prodtohier pth
-                  ON ph.id = pth.hierarchy_id
-                LEFT OUTER JOIN '.cms_db_prefix().'module_products pr
-                  ON pth.product_id = pr.id';
-    if( count($where) )
-      {
-	$query .= ' WHERE '.implode(' AND ',$where);
+      $tmp = self::hierarchy_get_tree($onehier['id'],$showall,$callback_fn);
+      if( is_array($tmp) && count($tmp) ) {
+	$onehier['children'] = $tmp;
       }
-    $query .= ' GROUP BY ph.id ORDER BY ph.hierarchy';
-    $data = $db->GetArray($query,$parms);
-
-    if( is_array($data) )
-      {
-	for( $i = 0; $i < count($data); $i++ )
-	  {
-	    if( $callback_fn != '' && function_exists($callback_fn) )
-	      {
-		$callback_fn($data[$i]);
-	      }
-
-	    $tmp = self::hierarchy_get_tree($data[$i]['id'],$showall,$callback_fn);
-	    if( is_array($tmp) && count($tmp) )
-	      {
-		$data[$i]['children'] = $tmp;
-	      }
-	  }
-
-	return $data;
-      }
-
-    return FALSE;
+      $out[] = $onehier;
+    }
+    return $out;
   }
 
 
@@ -260,41 +232,125 @@ class product_utils
   }
 
 
-  public static function get_product_attributes_full($product_id)
+  public static function get_categories($by_name = FALSE)
   {
-    $db = cmsms()->GetDb();
-    $data = array();
-
-    $query = 'SELECT * FROM '.cms_db_prefix().'module_products_attribsets
-              WHERE product_id = ?';
-    $tmp = $db->GetArray($query,array($product_id));	
-
-    $tmp2 = cge_array::extract_field($tmp,'attrib_set_id');
-    $q2 = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes
-            WHERE attrib_set_id IN ('.implode(',',$tmp2).') ORDER BY attrib_set_id ASC';
-    $tmp3 = $db->GetArray($q2);
-
-    for( $i = 0; $i < count($tmp); $i++ )
-      {
-	$row =& $tmp[$i];
-
-	$attribs = array();
-	for( $j = 0; $j < count($tmp3); $j++ )
-	  {
-	    $row2 =& $tmp3[$j];
-	    if( $row2['attrib_set_id'] < $row['attrib_set_id'] ) continue;
-	    if( $row2['attrib_set_id'] > $row['attrib_set_id'] ) break;
-
-	    $attribs[$row2['attrib_text']] = $row2;
-	  }
-	$data[$row['attrib_set_name']] = $attribs;
+    if( is_null(self::$_category_cache) ) {
+      $db = cmsms()->GetDb();
+      $query = 'SELECT * FROM '.cms_db_prefix().'module_products_categories ORDER BY name ASC';
+      $tmp = $db->GetArray($query);
+      self::$_category_cache = FALSE;
+      if( is_array($tmp) && count($tmp) ) {
+	self::$_category_cache = array();
+	foreach( $tmp as $row ) {
+	  $row = cge_array::to_object($row);
+	  self::$_category_cache[$row->id] = $row;
+	}
       }
+    }
 
-    if( !count($data) ) return false;
-    return $data;
+    if( !$by_name ) {
+      return self::$_category_cache;
+    }
+
+    if( is_array(self::$_category_cache) ) {
+      $out = array();
+      foreach( self::$_category_cache as $row ) {
+	$out[$row->name] = $row;
+      }
+      return $out;
+    }
   }
 
-} // product opts
+  public static function get_full_categories($by_name = FALSE)
+  {
+    $categories = self::get_categories();
+    if( !is_array($categories) || count($categories) == 0 ) {
+      return;
+    }
+    
+    $keys = array_keys($categories);
+    $fid = $keys[0]; // first field.
+    if( !isset(self::$_category_cache[$fid]->data) ) {
+      // we're gonna use the same cache again...
+      $db = cmsms()->GetDb();
+      $query = 'SELECT * FROM '.cms_db_prefix().'module_products_category_fields ORDER BY category_id,field_order';
+      $dbr = $db->GetArray($query);
+      foreach( $keys as $one ) {
+	$cat =& self::$_category_cache[$one];
+	if( !isset($cat->data) ) $cat->data = array();
+	for( $i = 0; $i < count($dbr); $i++ ) {
+	  $catid = $dbr[$i]['category_id'];
+	  $cat->data[] = $dbr[$i];
+	}
+      }
+    }
+
+    if( !$by_name ) {
+      return self::$_category_cache;
+    }
+
+    if( is_array(self::$_category_cache) ) {
+      $out = array();
+      foreach( self::$_category_cache as $row ) {
+	$out[$row->name] = $row;
+      }
+      return $out;
+    }
+  }
+
+  static public function get_fielddefs($admin = false,$public = true)
+  {
+    if( !is_array(self::$_flddef_cache) ) {
+      $entryarray = array();
+      $db = cmsms()->GetDB();
+		
+      if( $admin == true && $public == true ) {
+	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs ORDER BY item_order';
+      }
+      else if( $public == true ) {
+	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE public > 0 ORDER BY item_order';
+      }
+      else {
+	$query = 'SELECT * FROM '.cms_db_prefix().'module_products_fielddefs WHERE admin_only <= 0 ORDER BY item_order';
+      }
+      $dbresult = $db->GetArray($query);
+		
+      if( is_array($dbresult) ) {
+	foreach( $dbresult as $row ) {
+	  $onerow = new stdClass();
+				
+	  $onerow->id = $row['id'];
+	  $onerow->name = $row['name'];
+	  $onerow->prompt = $row['prompt'];
+	  $onerow->type = $row['type'];
+	  $tmp = explode("\n",$row['options']);
+	  $tmp2 = array();
+	  foreach( $tmp as $one ) {
+	    $one = trim($one);
+	    $tmp2[$one] = $one;
+	  }
+	  $onerow->options = $tmp2;
+	  $onerow->max_length = $row['max_length'];
+	  
+	  $entryarray[] = $onerow;
+	}
+      }
+      self::$_flddef_cache = $entryarray;
+    }
+		
+    return self::$_flddef_cache;
+  }
+
+  public static function can_do_pretty($action,$params) {
+    if( !isset($params['notpretty']) ) return TRUE;
+
+    if( strpos($params['notpretty'],'all') !== FALSE || strpos($params['notpretty'],$action) !== FALSE ) {
+      return FALSE;
+    }
+
+    return TRUE;
+  }
+} // product utils
 
 #
 # EOF
