@@ -42,7 +42,7 @@ switch( $oldversion )
   case '1.0':
   case '1.0.1':
     {
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $dict = NewDataDictionary($db);
       $taboptarray = array('mysql' => 'TYPE=MyISAM');
 
@@ -72,7 +72,7 @@ switch( $oldversion )
   case '2.0.1':
   case '2.0.2':
     {
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $dict = NewDataDictionary($db);
       $taboptarray = array('mysql' => 'TYPE=MyISAM');
 
@@ -90,7 +90,7 @@ switch( $oldversion )
 
   case '2.1':
     {
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $query = 'SELECT * FROM '.cms_db_prefix().'module_products_attributes';
       $dict = NewDataDictionary($db);
       $data = $db->GetArray($query);
@@ -170,7 +170,7 @@ switch( $oldversion )
   case '2.2.3':
   case '2.2.4':
 	{
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $dict = NewDataDictionary($db);
 
 	  $sqlarray = $dict->CreateIndexSQL('products_name',cms_db_prefix().'module_products','product_name');
@@ -232,7 +232,7 @@ switch( $oldversion )
   case '2.4.7':
   case '2.4.8':
 	{
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $dict = NewDataDictionary($db);
 
 	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_products", "sku C(25)");
@@ -244,7 +244,7 @@ switch( $oldversion )
 
   case '2.5':
 	{
-      $db =& $this->GetDb();
+      $db = $this->GetDb();
       $dict = NewDataDictionary($db);
 
 	  $sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_products", "alias C(255)");
@@ -292,7 +292,7 @@ switch( $oldversion )
 	}
 
 	// add a new field to the category fields table.
-	$db =& $this->GetDb();
+	$db = $this->GetDb();
 	$dict = NewDataDictionary($db);
 	$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_products_category_fields", "field_order I");
 	$dict->ExecuteSQLArray($sqlarray);
@@ -341,6 +341,38 @@ switch( $oldversion )
 		$order++;
 		$prev_category_id = $row['category_id'];
 	  }
+
+  }
+
+if( version_compare($oldversion,'2.14') < 0 )
+  {
+	function products_hiertree_update_order(&$tree)
+	{
+	  $order = 1;
+	  foreach( $tree as &$node )
+		{
+		  $node['item_order'] = $order++;
+		  if( isset($node['children']) )
+			{
+			  products_hiertree_update_order($node['children']);
+			}
+		}
+	}
+
+	$db = $this->GetDb();
+	$dict = NewDataDictionary($db);
+	$sqlarray = $dict->AddColumnSQL(cms_db_prefix()."module_products_hierarchy", "item_order I");
+	$dict->ExecuteSQLArray($sqlarray);
+
+	$tree = product_utils::hierarchy_get_tree();
+	products_hiertree_update_order($tree);
+	product_utils::hierarchy_save_tree($tree);
+  }
+
+
+if( version_compare($oldversion,'2.14') < 0 )
+  {
+	$this->AddEventHandler('CGEcommerceBase','OrderUpdated',FALSE);
   }
 
 // EOF
